/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 02691
 |              SERVICES RESEARCH OUTCOMES STUDY, 1995-1996
 |                (DATASET 0003: FOLLOW-UP INTERVIEW DATA)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 02691-0003-statasetup.do)
 |
 **************************************************************************/

set mem 10m  /* Allocating 10 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Services Research Outcomes Study, 1995-1996, Dataset 0003"

#delimit ;
label define MODE      -3 "MISSING" 1 "Inpatient" 2 "Residential"
                       3 "Outpatient Methadone Maintenance"
                       4 "Outpatient Drug-Free" ;
label define A1        -3 "MISSING" 1 "Male" 2 "Female" ;
label define A3        -3 "MISSING" 57 "57-64" 65 "65-74" 75 "75+" ;
label define A4        -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define A4A_1     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define A4A_2     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define A4A_3     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define A4A_4     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define A5        -3 "MISSING" 1 "White" 2 "Black or African American"
                       3 "Asian or Pacific Islander"
                       4 "Alaskan Native, Native American or Ameri"
                       5 "OTHER (SPECIFY)" ;
label define A6        -3 "MISSING" -2 "DON'T KNOW" 1 "Yes, diploma"
                       2 "Yes, GED" 3 "No" 4 "NEVER ATTENDED SCHOOL" ;
label define A7        -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "1st Grade"
                       2 "2nd Grade" 3 "3rd Grade" 4 "4th Grade"
                       5 "5th Grade" 6 "6th Grade" 7 "7th Grade"
                       8 "8th Grade" 9 "9th Grade" 10 "10th Grade"
                       11 "11th Grade" 12 "12th Grade" 13 "1 Year College"
                       14 "2 Years College" 15 "3 Years College"
                       16 "4 Years College" 17 "Graduate/Professional School" ;
label define A8        -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define A8A_1     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define A8A_2     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define A8A_3     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define A8A_4     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define A9        -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define A9A       -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define A10       -3 "MISSING" -2 "DON'T KNOW" 1 "Excellent" 2 "Good"
                       3 "Fair" 4 "Poor" ;
label define A11       -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define B1        -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes, dates correct/went to SROS Program"
                       2 "Yes, incorrect/went to SROS Program"
                       3 "Yes, wrong SROS Program/dates correct"
                       4 "No, never went to SROS Program" ;
label define B2        -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B2B       -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define B4        -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B5        -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define B5A       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B6_1      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B6_2      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B6_3      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B6_4      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B6_5      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B6_6      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B6_7      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B6_8      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B6_9      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B6_10     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B6_11     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B6_12     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B6_13     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B6_14     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B7_1      -3 "MISSING" 0 "No" 1 "Yes" ;
label define B7_2      -3 "MISSING" 0 "No" 1 "Yes" ;
label define B7_3      -3 "MISSING" 0 "No" 1 "Yes" ;
label define B7_4      -3 "MISSING" 0 "No" 1 "Yes" ;
label define B7_5      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B8A       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Very important" 2 "Somewhat important"
                       3 "Not important" 4 "NA (Not applicable)" ;
label define B8B       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Very important" 2 "Somewhat important"
                       3 "Not important" 4 "NA (Not applicable)" ;
label define B8C       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Very important" 2 "Somewhat important"
                       3 "Not important" 4 "NA (Not applicable)" ;
label define B8D       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Very important" 2 "Somewhat important"
                       3 "Not important" 4 "NA (Not applicable)" ;
label define B8E       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Very important" 2 "Somewhat important"
                       3 "Not important" 4 "NA (Not applicable)" ;
label define B8F       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Very important" 2 "Somewhat important"
                       3 "Not important" 4 "NA (Not applicable)" ;
label define B8G       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Very important" 2 "Somewhat important"
                       3 "Not important" 4 "NA (Not applicable)" ;
label define B9A       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" 3 "NA (Not applicable)" ;
label define B9B       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" 3 "NA (Not applicable)" ;
label define B9C       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" 3 "NA (Not applicable)" ;
label define B9D       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" 3 "NA (Not applicable)" ;
label define B9E       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" 3 "NA (Not applicable)" ;
label define B9F       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" 3 "NA (Not applicable)" ;
label define B10       -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define B11       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Very much" 2 "Somewhat" 3 "Not at all"
                       4 "DOESNT REMEMBER ANY STAFF PERSON" ;
label define B11A      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Very much" 2 "Somewhat"
                       3 "Not at all" ;
label define B12       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B12A_1    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B12A_2    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B12A_3    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B12A_4    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B12A_5    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B12A_6    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B12A_7    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B12A_8    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B12A_9    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B12A_10   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B12A_11   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B12A_12   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B12A_13   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B12B      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B12C      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW" ;
label define B13       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B14       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B15       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Excellent" 2 "Good" 3 "Fair" 4 "Poor" ;
label define B16       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define B16A      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B16B      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Too high" 2 "The right amount"
                       3 "Too low" ;
label define B17       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define B18       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Never" 2 "Less than one month"
                       3 "1 month to less than 6 months"
                       4 "6 months to less than one year" 5 "1-2 years"
                       6 "3-4 years, or" 7 "5 years or more" ;
label define B18AA     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Never" 2 "Less than once a week" 3 "Once a week"
                       4 "More than once a week" ;
label define B18AB     -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Never" 2 "Less than once a week"
                       3 "Once a week" 4 "More than once a week" ;
label define B18AC     -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Never" 2 "Less than once a week"
                       3 "Once a week" 4 "More than once a week" ;
label define B19A      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define B19B      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define B19C      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define B19D      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define B19E      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define B19F      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define B19G      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define B19H      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define B19I      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define B20       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Very helpful" 2 "Somewhat helpful"
                       3 "Not at all helpful" ;
label define BOX20A    -6 "LEGITIMATE SKIP" -3 "MISSING"
                       2 "USE START/END DATES FROM FACE SHEET FOR" ;
label define B21CODE   -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 0 "None" 1 "One time" 2 "Two times"
                       3 "Three times" 4 "Four times" 5 "Five times"
                       6 "6-10 times" 7 "11-15 times" 8 "16-30 times"
                       9 "31 times or more" ;
label define B21BYR    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW" ;
label define B21C      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Very helpful" 2 "Somewhat helpful"
                       3 "Not at all helpful" ;
label define B21D      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B21D2     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B21ECOD   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       0 "None" 1 "One time" 2 "Two times" 3 "Three times"
                       4 "Four times" 5 "Five times" 6 "6-10 times"
                       7 "11-15 times" 8 "16-30 times" 9 "31-50" ;
label define B21GY     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW" ;
label define B21H      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Very helpful" 2 "Somewhat helpful"
                       3 "Not at all helpful" ;
label define B22       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Less than one year" 2 "1-2 years" 3 "3-4 years"
                       4 "5 years or more" ;
label define B23A      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define B23B      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define B23C      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define B23D      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define B23E      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define B24A      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B24B      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B24C      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B25       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Never" 2 "Less than one month"
                       3 "1 month to less than 6 months"
                       4 "6 months to less than one year" 5 "1-2 years"
                       6 "3-4 years" 7 "5 years or more" ;
label define B25AA     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Never" 2 "Less than once a week" 3 "Once a week"
                       4 "More than once a week" ;
label define B25AB     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Never" 2 "Less than once a week" 3 "Once a week"
                       4 "More than once a week" ;
label define B25AC     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Never" 2 "Less than once a week" 3 "Once a week"
                       4 "More than once a week" ;
label define B26       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define B26A      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B27CODE   -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "One time"
                       2 "Two times" 3 "Three times" 4 "Four times"
                       5 "Five times" 6 "6-10 times" 7 "11-15 times"
                       8 "16-30 times" 9 "31 times or more" ;
label define B29A      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Inpatient" 2 "Residential"
                       3 "Outpatient (non-methadone)" 4 "Methadone"
                       5 "Something else" ;
label define B29B      -6 "LEGITIMATE SKIP" -3 "MISSING"
                       1 "Less than one month" 2 "One month" 3 "2-3 months"
                       4 "4-5 months" 5 "6-8 months" 6 "9-11 months"
                       7 "12 months or more" ;
label define B29C_1    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B29C_2    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B29C_3    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B29C_4    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B29C_5    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B29C_6    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B29C_7    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B29C_8    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B29C_9    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B29C_10   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B29C_11   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B29C_12   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B29C_13   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B29C_14   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B30A      -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Inpatient"
                       2 "Residential" 3 "Outpatient (non-methadone)"
                       4 "Methadone" 5 "Something else" ;
label define B30B      -6 "LEGITIMATE SKIP" -3 "MISSING"
                       1 "Less than one month" 2 "One month" 3 "2-3 months"
                       4 "4-5 months" 5 "6-8 months" 6 "9-11 months"
                       7 "12 months or more" ;
label define B30C_1    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B30C_2    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B30C_3    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B30C_4    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B30C_5    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B30C_6    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B30C_7    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B30C_8    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B30C_9    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B30C_10   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B30C_11   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B30C_12   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B30C_13   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B30C_14   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B31A      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Inpatient" 2 "Residential"
                       3 "Outpatient (non-methadone)" 4 "Methadone"
                       5 "Something else" ;
label define B31B      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Less than one month" 2 "One month" 3 "2-3 months"
                       4 "4-5 months" 5 "6-8 months" 6 "9-11 months"
                       7 "12 months or more" ;
label define B31C_1    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B31C_2    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B31C_3    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B31C_4    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B31C_5    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B31C_6    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B31C_7    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B31C_8    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B31C_9    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B31C_10   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B31C_11   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B31C_12   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B31C_13   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B31C_14   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       2 "No" ;
label define B32A      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Inpatient" 2 "Residential"
                       3 "Outpatient (non-methadone)" 4 "Methadone"
                       5 "Something else" ;
label define B32B      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Less than one month" 2 "One month" 3 "2-3 months"
                       4 "4-5 months" 5 "6-8 months" 6 "9-11 months"
                       7 "12 months or more" ;
label define B32C_1    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B32C_2    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B32C_3    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B32C_4    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B32C_5    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B32C_6    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B32C_7    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B32C_8    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B32C_9    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B32C_10   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B32C_11   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B32C_12   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B32C_13   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B32C_14   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       2 "No" ;
label define B33A      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Inpatient" 2 "Residential"
                       3 "Outpatient (non-methadone)" 4 "Methadone" ;
label define B33B      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Less than one month" 2 "One month" 3 "2-3 months"
                       4 "4-5 months" 5 "6-8 months" 6 "9-11 months"
                       7 "12 months or more" ;
label define B33C_1    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B33C_2    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B33C_3    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B33C_4    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B33C_5    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B33C_6    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       2 "No" ;
label define B33C_7    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B33C_8    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B33C_9    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B33C_10   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B33C_11   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B33C_12   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B33C_13   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B33C_14   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B34A      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B34B      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B34C      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define B35       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Never" 2 "Less than one month"
                       3 "1 month to less than 6 months"
                       4 "6 months to less than one year" 5 "1-2 years"
                       6 "3-4 years" 7 "5 years or more" ;
label define B35AA     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Never" 2 "Less than once a week" 3 "Once a week"
                       4 "More than once a week" ;
label define B35AB     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Never" 2 "Less than once a week" 3 "Once a week"
                       4 "More than once a week" ;
label define B35AC     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Never" 2 "Less than once a week" 3 "Once a week"
                       4 "More than once a week" ;
label define B36       -3 "MISSING" -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define B41_1     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B41_2     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B41_3     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B41_4     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B41_5     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B41_6     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B41_7     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B41_8     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B41_9     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B41_10    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B41_11    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B41_12    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B41_13    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define B42       -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define B43       -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define B44       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define B44A      -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Too high"
                       2 "The right amount" 3 "Too low" ;
label define B45       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define B46       -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Never" 2 "Less than one month"
                       3 "1 month to less than 6 months"
                       4 "6 months to less than one year" 5 "1-2 years"
                       6 "3-4 years" 7 "5 years or more" ;
label define B46AA     -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Never" 2 "Less than once a week"
                       3 "Once a week" 4 "More than once a week" ;
label define B46AB     -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Never" 2 "Less than once a week"
                       3 "Once a week" 4 "More than once a week" ;
label define B46AC     -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Never" 2 "Less than once a week"
                       3 "Once a week" 4 "More than once a week" ;
label define B47A      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Yes" 2 "No" 3 "NA (Not applicable)" ;
label define B47B      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" 3 "NA (Not applicable)" ;
label define B47C      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Yes" 2 "No" 3 "NA (Not applicable)" ;
label define B47D      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" 3 "NA (Not applicable)" ;
label define B47E      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" 3 "NA (Not applicable)" ;
label define B47F      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Yes" 2 "No" 3 "NA (Not applicable)" ;
label define B47G      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Yes" 2 "No" 3 "NA (Not applicable)" ;
label define B47H      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Yes" 2 "No" 3 "NA (Not applicable)" ;
label define B47I      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Yes" 2 "No" 3 "NA (Not applicable)" ;
label define B48       -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Yes" 2 "No" 3 "NA (Not applicable)" ;
label define C1AINHAL  -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define C1AALCOH  -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define C1AMARIJ  -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define C1ACRACK  -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define C1ACOCAI  -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define C1APCP    -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define C1AHALLU  -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define C1AHEROI  -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define C1AMTHDO  -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define C1AONARC  -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define C1AMETHA  -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define C1ADOWNR  -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define C1AODRUG  -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define C2INHAL   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define C3INHAL   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C3AINHAL  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 4 "11-20 days" 5 "21-30 days"
                       6 "Everyday" ;
label define C4INHAL   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C5INHAL   -6 "LEGITIMATE SKIP" -3 "MISSING" 2 "2-5 days"
                       3 "6-10 days" 4 "11-20 days" 5 "21-30 days"
                       6 "Everyday" ;
label define C6INHAL   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C7INHAL   -6 "LEGITIMATE SKIP" -3 "MISSING" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C8INHAL   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C8AINHAL  -6 "LEGITIMATE SKIP" -3 "MISSING" 2 "2-3 months"
                       3 "4-5 months" ;
label define C9INHAL   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None"
                       6 "Everyday" ;
label define C2ALCOH   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW" ;
label define C3ALCOH   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define C3AALCOH  -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       0 "None" 1 "One day" 2 "2-5 days" 3 "6-10 days"
                       4 "11-20 days" 5 "21-30 days" 6 "Everyday" ;
label define C4ALCOH   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C5ALCOH   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       0 "None" 1 "One day" 2 "2-5 days" 3 "6-10 days"
                       4 "11-20 days" 5 "21-30 days" 6 "Everyday" ;
label define C6ALCOH   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C7ALCOH   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       0 "None" 1 "One day" 2 "2-5 days" 3 "6-10 days"
                       4 "11-20 days" 5 "21-30 days" 6 "Everyday" ;
label define C8ALCOH   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define C8AALCOH  -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "1 month" 2 "2-3 months" 3 "4-5 months"
                       4 "6-8 months" 5 "9+ months" ;
label define C9ALCOH   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       0 "None" 1 "One day" 2 "2-5 days" 3 "6-10 days"
                       4 "11-20 days" 5 "21-30 days" 6 "Everyday" ;
label define C2MARIJ   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define C3MARIJ   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C3AMARIJ  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C4MARIJ   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C5MARIJ   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C6MARIJ   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define C7MARIJ   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C8MARIJ   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C8AMARIJ  -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "1 month"
                       2 "2-3 months" 3 "4-5 months" 4 "6-8 months"
                       5 "9+ months" ;
label define C9MARIJ   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C2CRACK   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define C3CRACK   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C3ACRACK  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C4CRACK   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C5CRACK   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C6CRACK   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C7CRACK   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C8CRACK   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C8ACRACK  -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "1 month"
                       2 "2-3 months" 3 "4-5 months" 4 "6-8 months"
                       5 "9+ months" ;
label define C9CRACK   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C2COCAI   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define C3COCAI   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C3ACOCAI  -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       0 "None" 1 "One day" 2 "2-5 days" 3 "6-10 days"
                       4 "11-20 days" 5 "21-30 days" 6 "Everyday" ;
label define C4COCAI   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C5COCAI   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       0 "None" 1 "One day" 2 "2-5 days" 3 "6-10 days"
                       4 "11-20 days" 5 "21-30 days" 6 "Everyday" ;
label define C6COCAI   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C7COCAI   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C8COCAI   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C8ACOCAI  -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "1 month"
                       2 "2-3 months" 3 "4-5 months" 4 "6-8 months"
                       5 "9+ months" ;
label define C9COCAI   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       0 "None" 1 "One day" 2 "2-5 days" 3 "6-10 days"
                       4 "11-20 days" 5 "21-30 days" 6 "Everyday" ;
label define C2PCP     -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define C3PCP     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C3APCP    -6 "LEGITIMATE SKIP" -3 "MISSING" 2 "2-5 days"
                       3 "6-10 days" 4 "11-20 days" 5 "21-30 days"
                       6 "Everyday" ;
label define C4PCP     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C5PCP     -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 4 "11-20 days" 5 "21-30 days" ;
label define C6PCP     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C7PCP     -6 "LEGITIMATE SKIP" -3 "MISSING" 5 "21-30 days" ;
label define C8PCP     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" ;
label define C8APCP    -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define C9PCP     -6 "LEGITIMATE SKIP" -3 "MISSING" 4 "11-20 days" ;
label define C2HALLU   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define C3HALLU   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C3AHALLU  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C4HALLU   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C5HALLU   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" ;
label define C6HALLU   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C7HALLU   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 4 "11-20 days" 5 "21-30 days" ;
label define C8HALLU   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C8AHALLU  -6 "LEGITIMATE SKIP" -3 "MISSING" 2 "2-3 months"
                       3 "4-5 months" 4 "6-8 months" 5 "9+ months" ;
label define C9HALLU   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       5 "21-30 days" ;
label define C2HEROI   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW" ;
label define C3HEROI   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define C3AHEROI  -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED"
                       0 "None" 1 "One day" 2 "2-5 days" 3 "6-10 days"
                       4 "11-20 days" 5 "21-30 days" 6 "Everyday" ;
label define C4HEROI   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define C5HEROI   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       0 "None" 1 "One day" 2 "2-5 days" 3 "6-10 days"
                       4 "11-20 days" 5 "21-30 days" 6 "Everyday" ;
label define C6HEROI   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C7HEROI   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C8HEROI   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C8AHEROI  -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "1 month"
                       2 "2-3 months" 3 "4-5 months" 4 "6-8 months"
                       5 "9+ months" ;
label define C9HEROI   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C2MTHDO   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define C3MTHDO   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C3AMTHDO  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days" 6 "Everyday" ;
label define C4MTHDO   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C5MTHDO   -6 "LEGITIMATE SKIP" -3 "MISSING" 2 "2-5 days"
                       3 "6-10 days" 4 "11-20 days" 5 "21-30 days" ;
label define C6MTHDO   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C7MTHDO   -6 "LEGITIMATE SKIP" -3 "MISSING" 2 "2-5 days"
                       3 "6-10 days" ;
label define C8MTHDO   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" ;
label define C8AMTHDO  -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "1 month"
                       2 "2-3 months" 4 "6-8 months" ;
label define C9MTHDO   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define C2ONARC   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define C3ONARC   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C3AONARC  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C4ONARC   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C5ONARC   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C6ONARC   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C7ONARC   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C8ONARC   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C8AONARC  -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "1 month"
                       2 "2-3 months" 3 "4-5 months" 4 "6-8 months"
                       5 "9+ months" ;
label define C9ONARC   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" ;
label define C2METHA   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define C3METHA   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C3AMETHA  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C4METHA   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C5METHA   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C6METHA   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C7METHA   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C8METHA   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C8AMETHA  -6 "LEGITIMATE SKIP" -3 "MISSING" 2 "2-3 months"
                       3 "4-5 months" 4 "6-8 months" 5 "9+ months" ;
label define C9METHA   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C2DOWNR   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define C3DOWNR   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C3ADOWNR  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C4DOWNR   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C5DOWNR   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C6DOWNR   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C7DOWNR   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C8DOWNR   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C8ADOWNR  -6 "LEGITIMATE SKIP" -3 "MISSING" 2 "2-3 months"
                       3 "4-5 months" 4 "6-8 months" 5 "9+ months" ;
label define C9DOWNR   -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       0 "None" 1 "One day" 2 "2-5 days" 5 "21-30 days"
                       6 "Everyday" ;
label define C2ODRUG   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define C3ODRUG   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C3AODRUG  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C4ODRUG   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C5ODRUG   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C6ODRUG   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C7ODRUG   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C8ODRUG   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C8AODRUG  -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "1 month"
                       2 "2-3 months" 3 "4-5 months" 4 "6-8 months"
                       5 "9+ months" ;
label define C9ODRUG   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days" 6 "Everyday" ;
label define C10       -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C11       -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C12_1     -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define C13_1     -6.0 "LEGITIMATE SKIP" -3.0 "MISSING" -1.0 "REFUSED" ;
label define C13_1A    -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED"
                       1 "Bottles" 2 "Cans" 3 "Glasses" 4 "Six packs"
                       5 "Pints" 6 "Quarts" 11 "Other (SPECIFY)" ;
label define C12_2     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define C13_2     -6.0 "LEGITIMATE SKIP" -3.0 "MISSING" ;
label define C13_2A    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Bottles"
                       3 "Glasses" 7 "Fifths" 11 "Other (SPECIFY)" ;
label define C12_3     -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define C13_3     -6.0 "LEGITIMATE SKIP" -3.0 "MISSING"
                       -2.0 "DON'T KNOW" ;
label define C13_3A    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       5 "1/2 Pints" 6 "Pints" 7 "Quarts" 8 "Fifths"
                       9 "Drinks" 10 "Shots" 11 "Other (SPECIFY)" ;
label define C15INHA   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Inhalants" ;
label define C15ALCO   -6 "LEGITIMATE SKIP" -3 "MISSING" 2 "Alcohol" ;
label define C15MARI   -6 "LEGITIMATE SKIP" -3 "MISSING"
                       3 "Marijuana/Hashish" ;
label define C15CRCK   -6 "LEGITIMATE SKIP" -3 "MISSING" 4 "Crack" ;
label define C15COCA   -6 "LEGITIMATE SKIP" -3 "MISSING" 5 "Cocaine Powder" ;
label define C15PCP    -6 "LEGITIMATE SKIP" -3 "MISSING" 6 "PCP/Angel Dust" ;
label define C15HALU   -6 "LEGITIMATE SKIP" -3 "MISSING"
                       7 "Hallucinogens/Psychedelics/LSD" ;
label define C15HERO   -6 "LEGITIMATE SKIP" -3 "MISSING" 8 "Heroin" ;
label define C15MTDO   -6 "LEGITIMATE SKIP" -3 "MISSING"
                       9 "Illegal Methadone" ;
label define C15ONRC   -6 "LEGITIMATE SKIP" -3 "MISSING" 10 "Other narcotics" ;
label define C15METH   -6 "LEGITIMATE SKIP" -3 "MISSING"
                       11 "Methamphetamines" ;
label define C15DOWN   -6 "LEGITIMATE SKIP" -3 "MISSING" 12 "Downers" ;
label define C15OTHR   -6 "LEGITIMATE SKIP" -3 "MISSING"
                       13 "Other drug (SPECIFY)" ;
label define C16INHA   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define C17INHA   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW" ;
label define C18INHA   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define C18AINHA  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C19INHA   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C19AINHA  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days" 6 "Everyday" ;
label define C20INHA   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C20AINHA  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 5 "21-30 days" ;
label define C21INHA   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" ;
label define C16ALCO   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define C17ALCO   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW" ;
label define C18ALCO   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define C18AALCO  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C19ALCO   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define C19AALCO  -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       0 "None" 1 "One day" 2 "2-5 days" 3 "6-10 days"
                       4 "11-20 days" 5 "21-30 days" 6 "Everyday" ;
label define C20ALCO   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define C20AALCO  -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       0 "None" 1 "One day" 2 "2-5 days" 3 "6-10 days"
                       4 "11-20 days" 5 "21-30 days" 6 "Everyday" ;
label define C21ALCO   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       0 "None" 1 "One day" 2 "2-5 days" 3 "6-10 days"
                       4 "11-20 days" 5 "21-30 days" 6 "Everyday" ;
label define C16MARI   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define C17MARI   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW" ;
label define C18MARI   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C18AMARI  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C19MARI   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C19AMARI  -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       0 "None" 1 "One day" 2 "2-5 days" 3 "6-10 days"
                       4 "11-20 days" 5 "21-30 days" 6 "Everyday" ;
label define C20MARI   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C20AMARI  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C21MARI   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C16CRCK   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define C17CRCK   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define C18CRCK   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C18ACRCK  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C19CRCK   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C19ACRCK  -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       0 "None" 1 "One day" 2 "2-5 days" 3 "6-10 days"
                       4 "11-20 days" 5 "21-30 days" 6 "Everyday" ;
label define C20CRCK   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C20ACRCK  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C21CRCK   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       0 "None" 1 "One day" 2 "2-5 days" 3 "6-10 days"
                       4 "11-20 days" 5 "21-30 days" 6 "Everyday" ;
label define C16COCA   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define C17COCA   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW" ;
label define C18COCA   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C18ACOCA  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C19COCA   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C19ACOCA  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C20COCA   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define C20ACOCA  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C21COCA   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C16PCP    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define C17PCP    -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define C18PCP    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C18APCP   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C19PCP    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C19APCP   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 6 "Everyday" ;
label define C20PCP    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C20APCP   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" ;
label define C21PCP    -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None"
                       2 "2-5 days" ;
label define C16HALU   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define C17HALU   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define C18HALU   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define C18AHALU  -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       0 "None" 1 "One day" 2 "2-5 days" 3 "6-10 days"
                       4 "11-20 days" 5 "21-30 days" 6 "Everyday" ;
label define C19HALU   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C19AHALU  -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       0 "None" 1 "One day" 2 "2-5 days" 3 "6-10 days"
                       4 "11-20 days" 5 "21-30 days" 6 "Everyday" ;
label define C20HALU   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C20AHALU  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" ;
label define C21HALU   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" ;
label define C16HERO   -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define C17HERO   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define C18HERO   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C18AHERO  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C19HERO   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C19AHERO  -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       0 "None" 1 "One day" 2 "2-5 days" 3 "6-10 days"
                       4 "11-20 days" 5 "21-30 days" 6 "Everyday" ;
label define C20HERO   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C20AHERO  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 5 "21-30 days" 6 "Everyday" ;
label define C21HERO   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 5 "21-30 days" 6 "Everyday" ;
label define C16MTDO   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define C17MTDO   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define C18MTDO   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define C18AMTDO  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C19MTDO   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C19AMTDO  -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       0 "None" 1 "One day" 2 "2-5 days" 3 "6-10 days"
                       4 "11-20 days" 6 "Everyday" ;
label define C20MTDO   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C20AMTDO  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days" 6 "Everyday" ;
label define C21MTDO   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None"
                       3 "6-10 days" 4 "11-20 days" 6 "Everyday" ;
label define C16ONRC   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define C17ONRC   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define C18ONRC   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define C18AONRC  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C19ONRC   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C19AONRC  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C20ONRC   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C20AONRC  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C21ONRC   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C16METH   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define C17METH   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define C18METH   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C18AMETH  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C19METH   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C19AMETH  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C20METH   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C20AMETH  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days" 6 "Everyday" ;
label define C21METH   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" ;
label define C16DOWN   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define C17DOWN   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define C18DOWN   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C18ADOWN  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C19DOWN   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C19ADOWN  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C20DOWN   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C20ADOWN  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C21DOWN   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       0 "None" 1 "One day" 2 "2-5 days" 3 "6-10 days"
                       4 "11-20 days" 5 "21-30 days" 6 "Everyday" ;
label define C16OTHR   -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define C17OTHR   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define C18OTHR   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C18AOTHR  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C19OTHR   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C19AOTHR  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days" 6 "Everyday" ;
label define C20OTHR   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C20AOTHR  -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days" 6 "Everyday" ;
label define C21OTHR   -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 4 "11-20 days" 6 "Everyday" ;
label define C22       -3 "MISSING" 1 "Yes" 2 "No" ;
label define C23       -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C24_1     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C25_1     -6.0 "LEGITIMATE SKIP" -3.0 "MISSING" ;
label define C25_1A    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Bottles" 2 "Cans"
                       3 "Glasses" 4 "Six packs" 6 "Quarts"
                       11 "Other (SPECIFY)" ;
label define C24_2     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C25_2     -6.0 "LEGITIMATE SKIP" -3.0 "MISSING" ;
label define C25_2A    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Bottles"
                       3 "Glasses" 7 "Fifths" 11 "Other (SPECIFY)" ;
label define C24_3     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define C25_3     -6.00 "LEGITIMATE SKIP" -3.00 "MISSING" ;
label define C25_3A    -6 "LEGITIMATE SKIP" -3 "MISSING" 5 "1/2 Pints"
                       6 "Pints" 7 "Quarts" 8 "Fifths" 9 "Drinks" 10 "Shots"
                       11 "Other (SPECIFY)" ;
label define C27       -3 "MISSING" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define C27A      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" ;
label define C27B      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define C28       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "None" 2 "1-9 times" 3 "10-29"
                       4 "30-49 times" 5 "50-99 times" 6 "100-199"
                       7 "200 times or more" 8 "R NEVER INJECTED DRUGS" ;
label define C28A      -6 "LEGITIMATE SKIP" -3 "MISSING" 0 "None" 1 "One day"
                       2 "2-5 days" 3 "6-10 days" 4 "11-20 days"
                       5 "21-30 days" 6 "Everyday" ;
label define C28B      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define C28CA     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Very Helpful"
                       2 "Somewhat Helpful" 3 "Not at all Helpful" ;
label define C28CB     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Very Helpful"
                       2 "Somewhat Helpful" 3 "Not at all Helpful" ;
label define C28CC     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Very Helpful" 2 "Somewhat Helpful"
                       3 "Not at all Helpful" ;
label define C29       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "None" 2 "1-9 times" 3 "10-29 times"
                       4 "30-49 times" 5 "50-99 times" 6 "100-199 times"
                       7 "200 times or more" 8 "R HAS NEVER INJECTED DRUGS" ;
label define C29A      -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No"
                       3 "R HAS NEVER INJECTED DRUGS" ;
label define D1        -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D1A       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define D2        -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 0 "None" 1 "One time" 2 "Two times"
                       3 "Three times" 4 "Four times" 5 "Five times"
                       6 "6-10 times" 7 "11-15 times" 8 "16-30 times"
                       9 "31-50 times" 10 "51 times or more" ;
label define D3        -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 0 "None" 1 "One time" 2 "Two times"
                       3 "Three times" 4 "Four times" 5 "Five times"
                       6 "6-10 times" 7 "11-15 times" 8 "16-30 times"
                       9 "31-50 times" 10 "51 times or more" ;
label define D4        -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D5        -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" 3 "R NEVER INCARCERATED/UNDER SUPERVISION" ;
label define D6A       -3 "MISSING" 1 "Yes" 2 "No" ;
label define D6B       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define D6C       -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define D6D       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define D6E       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define D6F       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define D6G       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define D7        -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define D7AA      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define D7BA      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Less than one year" 2 "1-2 years" 3 "3-4 years"
                       4 "5 years or more" ;
label define D7AB      -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define D7BB      -6 "LEGITIMATE SKIP" -3 "MISSING"
                       1 "Less than one year" 2 "1-2 years" 3 "3-4 years"
                       4 "5 years or more" ;
label define D7AC      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define D7BC      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Less than one year" 2 "1-2 years" 3 "3-4 years"
                       4 "5 years or more" ;
label define D7AD      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define D7BD      -6 "LEGITIMATE SKIP" -3 "MISSING"
                       1 "Less than one year" 2 "1-2 years" 3 "3-4 years" ;
label define D7AE      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D7BE      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Less than one year" 2 "1-2 years" 3 "3-4 years"
                       4 "5 years or more" ;
label define D7AF      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define D7BF      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Less than one year" 2 "1-2 years" 3 "3-4 years"
                       4 "5 years or more" ;
label define D7AG      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D7BG      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Less than one year" 2 "1-2 years" ;
label define D8        -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define D9        -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define D9A_1     -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D9A_2     -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D9A_3     -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D9A_4     -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D9A_5     -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D9A_6     -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D9A_7     -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D9A_8     -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D9A_9     -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D9A_10    -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D9A_11    -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 2 "No" ;
label define D9A_12    -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D9A_13    -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D9A_14    -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D9A_15    -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D10       -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D10A      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "More" 2 "Less" 3 "About the same"
                       4 "NEVER DID ILLEGAL ACTIVITY BEFORE PROGRA" ;
label define D11       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D12A      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D13A      -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define D13ANUM   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Days" 2 "Weeks"
                       3 "Months" 4 "Years" ;
label define D12B      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D13B      -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define D13BNUM   -6 "LEGITIMATE SKIP" -3 "MISSING" 2 "Weeks" 3 "Months"
                       4 "Years" ;
label define D12C      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D13C      -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define D13CNUM   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Days" 3 "Months"
                       4 "Years" ;
label define D12D      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D13D      -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define D13DNUM   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Days" 2 "Weeks"
                       3 "Months" 4 "Years" ;
label define D12E      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D13E      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" ;
label define D13ENUM   -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED"
                       1 "Days" 2 "Weeks" 3 "Months" 4 "Years" ;
label define D12F      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D13F      -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define D13FNUM   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Days" 2 "Weeks"
                       3 "Months" 4 "Years" ;
label define D12G      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D13G      -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define D13GNUM   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Days" 2 "Weeks"
                       3 "Months" ;
label define D14       -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 0 "NEVER" 1 "One time"
                       2 "Two time" 3 "Three times" 4 "Four times"
                       5 "Five times" 6 "6-10 times" 7 "11-15 times"
                       8 "16-30 times" 9 "31-50 times" 10 "51 times or more" ;
label define D14A      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define D15       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D15A      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D15B      -6 "LEGITIMATE SKIP" -3 "MISSING"
                       1 "Less than one month" 2 "One month" 3 "2-3 months"
                       4 "4-5 months" 5 "6-8 months" 6 "9-11 months"
                       7 "Twelve months/entire year" ;
label define D16A      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D17A      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Less than one year" 2 "1-2 years" 3 "3-4 years"
                       4 "5 years or more" ;
label define D16B      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D17B      -6 "LEGITIMATE SKIP" -3 "MISSING"
                       1 "Less than one year" 2 "1-2 years" 3 "3-4 years"
                       4 "5 years or more" ;
label define D16C      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D17C      -6 "LEGITIMATE SKIP" -3 "MISSING"
                       1 "Less than one year" 2 "1-2 years" 3 "3-4 years" ;
label define D16D      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D17D      -6 "LEGITIMATE SKIP" -3 "MISSING"
                       1 "Less than one year" 2 "1-2 years" 3 "3-4 years"
                       4 "5 years or more" ;
label define D16E      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D17E      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Less than one year" 2 "1-2 years" 3 "3-4 years"
                       4 "5 years or more" ;
label define D16F      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D17F      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Less than one year" 2 "1-2 years" 3 "3-4 years"
                       4 "5 years or more" ;
label define D16G      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D17G      -6 "LEGITIMATE SKIP" -3 "MISSING"
                       1 "Less than one year" 2 "1-2 years"
                       4 "5 years or more" ;
label define D18       -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D19       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Less than one year" 2 "1-2 years"
                       3 "3-4 years" 4 "5 years or more" ;
label define D20       -3 "MISSING" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D20A      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D20B      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D20C      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D20D      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D20E      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D20F      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D21       -3 "MISSING" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D21A      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D21B      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D21C      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D21D      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D21E      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D21F      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D22       -3 "MISSING" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D22A      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D22B      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D22C      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D22D      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D22E      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D22F      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D23       -3 "MISSING" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D23A      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D23B      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D23C      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D23D      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D23E      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D23F      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D24       -3 "MISSING" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D24A      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D24B      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D24C      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D24D      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D24E      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D24F      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D25       -3 "MISSING" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D25A      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D25B      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D25C      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D25D      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D25E      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D25F      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D26       -3 "MISSING" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D26A      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D26B      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D26C      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D26D      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D26E      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D26F      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D27       -3 "MISSING" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D27A      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D27B      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D27C      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D27D      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D27E      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D27F      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D28       -3 "MISSING" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D28A      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D28B      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D28C      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D28D      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D28E      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D28F      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D29       -3 "MISSING" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D29A      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D29B      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D29C      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D29D      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D29E      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D29F      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D30       -3 "MISSING" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D30A      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D30B      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D30C      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D30D      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 2 "No" ;
label define D30E      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D30F      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 2 "No" ;
label define D31       -3 "MISSING" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D31A      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D31B      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D31C      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D31D      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D31E      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D31F      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D32       -3 "MISSING" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D32A      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D32B      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D32C      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D32D      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 2 "No" ;
label define D32E      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D32F      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D33       -3 "MISSING" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D33A      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D33B      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D33C      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D33D      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 2 "No" ;
label define D33E      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D33F      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D34       -3 "MISSING" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D34A      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D34B      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D34C      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D34D      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D34E      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D34F      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D35       -3 "MISSING" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D35A      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D35B      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D35C      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D35D      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 2 "No" ;
label define D35E      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D35F      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D36       -3 "MISSING" -1 "REFUSED" 1 "Yes" 2 "No"
                       3 "R CURRENTLY INCARCERATED" ;
label define D36AA     -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define D36AB     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D36AC     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define D35AD     -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define E1        -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define E1A       -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" 3 "MARRIAGE WAS ANNULLED" ;
label define E2        -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define E3        -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" ;
label define E4MONTH   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define E4YEAR    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define E5        -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define E6        -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Less than one year"
                       2 "1-2 years" 3 "3-4 years" 4 "5 years or more" ;
label define E7        -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED"
                       1 "Activate skip" ;
label define E8A       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define E8B       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define E9        -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Less than one month" 2 "1-6 months"
                       3 "7-11 months" 4 "1-2 years" 5 "3-5 years"
                       6 "More than five years" 7 "NONE"
                       8 "R WAS NOT LIVING WITH PARTNER" ;
label define E10       -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED"
                       1 "Less than one month" 2 "1-2 months" 3 "3-4 months"
                       4 "5-6 months" 5 "7-8 months" 6 "9-11 months"
                       7 "12 months/entire year" 8 "NONE"
                       9 "R WAS NOT LIVING WITH PARTNER" ;
label define F1        -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" 3 "NEVER KNEW NATURAL MOTHER" ;
label define F2        -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" 3 "NEVER KNEW NATURAL FATHER" ;
label define F3        -3 "MISSING" -1 "REFUSED" 1 "Yes, with parents"
                       2 "Yes, with mother only" 3 "Yes, with father only"
                       4 "No" ;
label define F3A       -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" ;
label define F3B       -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" ;
label define F4        -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Never w/parents" 2 "Never w/mom"
                       3 "Never w/dad" 4 "Lived w/both" ;
label define F5        -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 0 "NEVER ATTENDED SCHOOL"
                       1 "1st Grade" 2 "2nd Grade" 3 "3rd Grade"
                       4 "4th Grade" 5 "5th Grade" 6 "6th Grade"
                       7 "7th Grade" 8 "8th Grade" 9 "9th Grade"
                       10 "10th Grade" 11 "11th Grade" 12 "12th Grade"
                       13 "1 Year College" 14 "2 Years College"
                       15 "3 Years College" 16 "4 Years College"
                       17 "Graduate/Professional School" ;
label define F5A       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes, diploma" 2 "Yes, GED" 3 "No" ;
label define F6        -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 0 "NEVER ATTENDED SCHOOL"
                       1 "1st Grade" 2 "2nd Grade" 3 "3rd Grade"
                       4 "4th Grade" 5 "5th Grade" 6 "6th Grade"
                       7 "7th Grade" 8 "8th Grade" 9 "9th Grade"
                       10 "10th Grade" 11 "11th Grade" 12 "12th Grade"
                       13 "1 Year College" 14 "2 Years College"
                       15 "3 Years College" 16 "4 Years College"
                       17 "Graduate/Professional School" ;
label define F6A       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes, diploma" 2 "Yes, GED" 3 "No" ;
label define F7        -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define F8        -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define F8A       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW" ;
label define F9        -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define F10       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 6 "6+" ;
label define F10A      -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define F11       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define F11A      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       6 "6+" ;
label define F12       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define F12A      -6 "LEGITIMATE SKIP" -3 "MISSING" 6 "6+" ;
label define F13       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define F13A      -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No"
                       3 "GAVE UP CUSTODY TO GO TO TREATMENT" ;
label define F13B      -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No"
                       3 "REGAINED CUSTODY BY COMPLETING TREATMENT" ;
label define F13C      -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No"
                       3 "GAVE UP CUSTODY TO GO TO TREATMENT" ;
label define F13D      -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No"
                       3 "REGAINED CUSTODY BY COMPLETING TREATMENT" ;
label define F13E      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" 3 "GAVE UP CUSTODY TO GO TO TREATMENT" ;
label define F13F      -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No"
                       3 "REGAINED CUSTODY BY COMPLETING TREATMENT" ;
label define F14       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define F14A      -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 6 "6+" ;
label define F15       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define F15A      -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "In shelters"
                       2 "On the street" 3 "Both" ;
label define F15B      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       0 "None" 1 "Less than 1 month" 2 "1-6 months"
                       3 "7-12 months" 4 "13-18 months" 5 "19-30 months"
                       6 "31-42 months" 7 "43-54 months"
                       9 "HOMELESS IN SHELTERS ENTIRE TIME" ;
label define F15C      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       0 "None" 1 "Less that 1 month" 2 "1-6 months"
                       3 "7-12 months" 4 "13-18 months" 5 "19-30 months"
                       6 "31-42 months" 7 "43-54 months"
                       8 "More than 54 months"
                       9 "HOMELESS ON STREET ENTIRE TIME" ;
label define F16       -3 "MISSING" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define F16A      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       0 "None" 1 "Less than 1 month" 2 "1-6 months"
                       3 "7-12 months" 4 "13-18 months" 5 "19-30 months"
                       6 "31-42 months" 7 "43-54 months"
                       8 "More than 54 months" 9 "ENTIRE TIME" ;
label define F17       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define F17A      -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "In shelters"
                       2 "On the street" 3 "Both" ;
label define F17B      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 0 "None" 1 "Less than 1 month"
                       2 "1-6 months" 3 "7-12 months" 4 "13-18 months"
                       5 "19-30 months" 6 "31-42 months"
                       8 "More than 54 months"
                       9 "HOMELESS IN SHELTERS ENTIRE TIME" ;
label define F17C      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       0 "None" 1 "Less than 1 month" 2 "1-6 months"
                       3 "7-12 months" 4 "13-18 months" 5 "19-30 months"
                       6 "31-42 months" 7 "43-54 months"
                       8 "More than 54 months"
                       9 "HOMELESS ON STREET ENTIRE TIME" ;
label define F19       -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define F19A_1    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define F19A_2    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define F19A_3    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define F19A_4    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define F19A_5    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define F19A_6    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define F19A_7    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define F19A_8    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define F19A_9    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define F19A_10   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define F19B_0    -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define F19B_1    -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define F19B_2    -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       2 "No" ;
label define F19B_3    -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define F19B_4    -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       2 "No" ;
label define F19B_5    -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       2 "No" ;
label define F19B_6    -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define F19B_7    -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define F19B_8    -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define F19B_9    -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define F19B_10   -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define F19B_11   -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define F19B_12   -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define F19B_13   -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define F19B_14   -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define F19B_15   -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define F19B_16   -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define F19B_17   -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define F19C      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define G1        -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G2        -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G3        -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define G3A       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G3B       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "All" 2 "Some" 3 "None" ;
label define G4        -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G5        -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "All" 2 "Some" 3 "None"
                       4 "R NEVER USED ALCOHOL" ;
label define G6        -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "All" 2 "Some" 3 "None" 4 "R NEVER USED DRUGS" ;
label define G7        -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define G8        -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "All" 2 "Some" 3 "None" 4 "R NEVER USED ALCOHOL" ;
label define G9        -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "All" 2 "Some" 3 "None" 4 "R NEVER USED DRUGS" ;
label define G10       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G11       -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define G12       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define G13       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define G14       -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define G15       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW" ;
label define G16       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" 3 "R NEVER USED ALCOHOL" ;
label define G17       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" 3 "R NEVER USED DRUGS" ;
label define G18       -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define G19       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G20       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Often" 2 "Sometimes" 3 "Rarely" 4 "Never" ;
label define G20A      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G20B      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "All" 2 "Some" 3 "None" ;
label define G21       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Often" 2 "Sometimes" 3 "Rarely" 4 "Never" ;
label define G22       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "All" 2 "Some" 3 "None" 4 "R NEVER USED ALCOHOL" ;
label define G23       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "All" 2 "Some" 3 "None" 4 "R NEVER USED DRUGS" ;
label define G24       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Often" 2 "Sometimes" 3 "Rarely" 4 "Never" ;
label define G25       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "All" 2 "Some" 3 "None" 4 "R NEVER USED ALCOHOL" ;
label define G26       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "All" 2 "Some" 3 "None" 4 "R NEVER USED DRUGS" ;
label define G27       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G28       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G28A      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G28B      -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "All" 2 "Some"
                       3 "None" ;
label define G29       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G30       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "All" 2 "Some" 3 "None" 4 "R NEVER USED ALCOHOL" ;
label define G31       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "All" 2 "Some" 3 "None" 4 "R NEVER USED DRUGS" ;
label define G32       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G33       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "All" 2 "Some" 3 "None" 4 "R NEVER USED ALCOHOL" ;
label define G34       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "All" 2 "Some" 3 "None" 4 "R NEVER USED DRUGS" ;
label define G35       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G36       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define G37       -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" ;
label define G38       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define G39       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW" ;
label define G40       -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define G41       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define G42       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G43       -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define G44       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW" ;
label define G45       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW" ;
label define G46       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G47       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW" ;
label define G48       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED"
                       1 "Excellent" 2 "Good" 3 "Fair" 4 "Poor" ;
label define G49       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED"
                       1 "Excellent" 2 "Good" 3 "Fair" 4 "Poor" ;
label define G50       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED"
                       1 "Excellent" 2 "Good" 3 "Fair" 4 "Poor" ;
label define G51A      -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G51B      -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G51C      -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G51D      -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G51E      -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G51F      -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G51G      -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G51H      -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G51I      -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G51J      -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G51K      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" 3 "R IS MALE" ;
label define G51AA     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G51BA     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G51AB     -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define G51BB     -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "Yes" 2 "No" ;
label define G51AC     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define G51BC     -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G51AD     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define G51BD     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G51AE     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G51BE     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G51AF     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G51BF     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define G51AG     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G51BG     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define G51AH     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G51BH     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define G51AI     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define G51BI     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define G51AJ     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define G51BJ     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define G51AK     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G51BK     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define G52       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G53       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G54       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       100 "100+" ;
label define G55       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G56       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW" ;
label define G57       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G58       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       100 "100+" ;
label define G59       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G60       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW" ;
label define G61       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G62       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G63       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "One time" 2 "2-9 times" 3 "10-19 times"
                       4 "20-49 times" 5 "50-99 times" 6 "100 or more times" ;
label define G64       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G65       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "One time" 2 "2-9 times"
                       3 "10-19 times" 4 "20-49 times" 5 "50-99 times"
                       6 "100 or more times" ;
label define G66       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G67       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G68       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define G69       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G70       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define G71       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G72       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G73       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW" ;
label define G74       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define G75       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW" ;
label define G76       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW" ;
label define G77       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "One time"
                       2 "2-9 times" 3 "10-19 times" 4 "20-49 times"
                       5 "50-99 times" 6 "More than 100 times"
                       7 "NONE/NEVER SAW A DOCTOR" ;
label define G78       -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       1 "One time" 2 "2-9 times" 3 "10-19 times"
                       4 "20-49 times" 5 "50-99 times"
                       6 "More than 100 times" 7 "NONE/NEVER SAW A DOCTOR" ;
label define G79       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED"
                       1 "One person" 2 "2-10 persons" 3 "11-25 persons"
                       4 "26-100 persons" 5 "100-500 persons"
                       6 "More than 500 persons" 7 "NONE" ;
label define G80       -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "One person"
                       2 "2-10 persons" 3 "11-25 persons" 4 "26-100 persons"
                       5 "100-500 persons" 6 "More than 500 persons" 7 "NONE" ;
label define G81       -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G82       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G83       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define G84       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" 3 "RESULTS POSITIVE"
                       4 "RESULTS NEGATIVE" ;
label define G86       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define G87       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G88       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define G89       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" 3 "RESULTS POSITIVE"
                       4 "RESULTS NEGATIVE" ;
label define G90       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define G91       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G92       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G93       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "One time" 2 "2-5 times" 3 "6-10 times"
                       4 "11-25 times" 5 "26-100 times"
                       6 "More than 100 times" ;
label define G95       -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define G96       -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define G97       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define G98       -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define G99       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "One time" 2 "2-5 times" 3 "6-10 times"
                       4 "11-25 times" 5 "26-100 times"
                       6 "More than 100 times" ;
label define H1        -3 "MISSING" -1 "REFUSED" 1 "Yes" 2 "No"
                       3 "R CURRENTLY HAS FULL-TIME JOB" ;
label define H2        -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define H3        -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Less than one year" 2 "1-2 years"
                       3 "3-4 years" 4 "5 years or more" ;
label define H3BDOL    -6.00 "LEGITIMATE SKIP" -3.00 "MISSING"
                       -2.00 "DON'T KNOW" -1.00 "REFUSED" 100000.00 "100000+" ;
label define H3BRATE   -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Per hour" 2 "Per day"
                       3 "Per week" 4 "Every two weeks" 5 "Bi-monthly"
                       6 "Monthly" 7 "Per year" ;
label define H4        -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Less than one year" 2 "1-2 years"
                       3 "3-4 years" 4 "5 years or more" ;
label define H4ADOL    -6.00 "LEGITIMATE SKIP" -3.00 "MISSING"
                       -2.00 "DON'T KNOW" -1.00 "REFUSED" 100000.00 "100000+" ;
label define H4ARATE   -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Per hour" 2 "Per day" 3 "Per week"
                       4 "Every two weeks" 5 "Bi-monthly" 6 "Monthly"
                       7 "Per year" ;
label define SAME1ST   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define H6        -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No"
                       3 "R CURRENTLY HAS FULL-TIME JOB" ;
label define H7        -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Less than one year" 2 "1-2 years"
                       3 "3-4 years" 4 "5 years or more" ;
label define SAME2ND   -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define H7BDOL    -6.00 "LEGITIMATE SKIP" -3.00 "MISSING"
                       -2.00 "DON'T KNOW" -1.00 "REFUSED" 100000.00 "100000+" ;
label define H7ARATE   -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Per hour" 2 "Per day"
                       3 "Per week" 4 "Every two weeks" 5 "Bi-monthly"
                       6 "Monthly" 7 "Per year" ;
label define H8        -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Less than one year" 2 "1-2 years" 3 "3-4 years"
                       4 "5 years or more" ;
label define H8ADOL    -6.00 "LEGITIMATE SKIP" -3.00 "MISSING"
                       -2.00 "DON'T KNOW" -1.00 "REFUSED" 100000.00 "100000+" ;
label define H8ARATE   -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Per hour" 2 "Per day"
                       3 "Per week" 4 "Every two weeks" 5 "Bi-monthly"
                       6 "Monthly" 7 "Per year" ;
label define SAME3RD   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define H10       -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define H10A      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW" ;
label define H10BDOL   -6.00 "LEGITIMATE SKIP" -3.00 "MISSING"
                       -1.00 "REFUSED" 100000.00 "100000+" ;
label define H10BRTE   -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Per hour" 2 "Per day"
                       3 "Per week" 4 "Every two weeks" 5 "Bi-monthly"
                       6 "Monthly" 7 "Per year" ;
label define SAME4TH   -6 "LEGITIMATE SKIP" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define H11       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define H12       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define H13       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Less than one year" 2 "1-2 years" 3 "3-4 years"
                       4 "5 years or more" ;
label define SAME5TH   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define H13BDOL   -6.00 "LEGITIMATE SKIP" -3.00 "MISSING"
                       -2.00 "DON'T KNOW" -1.00 "REFUSED" ;
label define H13BRTE   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Per hour" 2 "Per day" 3 "Per week"
                       4 "Every two weeks" 6 "Monthly" 7 "Per year" ;
label define H14       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Less than one year" 2 "1-2 years" 3 "3-4 years"
                       4 "5 years or more" ;
label define H14ADOL   -6.00 "LEGITIMATE SKIP" -5.00 "NOT APPLICABLE"
                       -3.00 "MISSING" -2.00 "DON'T KNOW" -1.00 "REFUSED" ;
label define H14ARTE   -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Per hour" 2 "Per day"
                       3 "Per week" 4 "Every two weeks" 6 "Monthly"
                       7 "Per year" ;
label define SAME6TH   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define H15       -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Less than one year" 2 "1-2 years"
                       3 "3-4 years" ;
label define SAME7TH   -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" 1 "Yes" 2 "No" ;
label define H15B      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Less than one year" 2 "1-2 years" 3 "3-4 years"
                       4 "5 years or more" ;
label define H15CDOL   -6.00 "LEGITIMATE SKIP" -3.00 "MISSING"
                       -2.00 "DON'T KNOW" -1.00 "REFUSED" ;
label define H15CRTE   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Per hour" 2 "Per day" 3 "Per week"
                       4 "Every two weeks" 6 "Monthly" 7 "Per year" ;
label define H17       -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define H17A      -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define H17BDOL   -6.00 "LEGITIMATE SKIP" -3.00 "MISSING"
                       -2.00 "DON'T KNOW" -1.00 "REFUSED" ;
label define H17BRTE   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Per hour" 2 "Per day" 3 "Per week"
                       4 "Every two weeks" 6 "Monthly" 7 "Per year" ;
label define SAME8TH   -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define H19       -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define H19A_1    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define H19A_2    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define H19A_3    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define H19A_4    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define H19A_5    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define H19A_6    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define H19A_7    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define H19A_8    -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define H19B      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Less than half" 2 "Half or more"
                       3 "All" ;
label define H21A      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define H22A      -6.00 "LEGITIMATE SKIP" -3.00 "MISSING"
                       -2.00 "DON'T KNOW" -1.00 "REFUSED" ;
label define H22ATIM   -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Per week"
                       2 "Per month" 3 "Per year" ;
label define H21B      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define H22B      -6.00 "LEGITIMATE SKIP" -3.00 "MISSING"
                       -2.00 "DON'T KNOW" -1.00 "REFUSED" ;
label define H22BTIM   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Per week" 2 "Per month" 3 "Per year" ;
label define H21C      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define H22C      -6.00 "LEGITIMATE SKIP" -3.00 "MISSING"
                       -2.00 "DON'T KNOW" -1.00 "REFUSED" ;
label define H22CTIM   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Per week" 2 "Per month" 3 "Per year" ;
label define H21D      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define H22D      -6.00 "LEGITIMATE SKIP" -3.00 "MISSING"
                       -2.00 "DON'T KNOW" -1.00 "REFUSED" ;
label define H22DTIM   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Per week" 2 "Per month" 3 "Per year" ;
label define H21E      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define H22E      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define H22ETIM   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 2 "Per month" 3 "Per year" ;
label define H21F      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define H22F      -6.00 "LEGITIMATE SKIP" -3.00 "MISSING"
                       -2.00 "DON'T KNOW" -1.00 "REFUSED" ;
label define H22FTIM   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Per week" 2 "Per month" 3 "Per year" ;
label define H21G      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define H22G      -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" ;
label define H22GTIM   -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Per week" 2 "Per month" 3 "Per year" ;
label define H21H      -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define H22H      -6.00 "LEGITIMATE SKIP" -5.00 "NOT APPLICABLE"
                       -3.00 "MISSING" -2.00 "DON'T KNOW" -1.00 "REFUSED" ;
label define H22HTIM   -6 "LEGITIMATE SKIP" -5 "NOT APPLICABLE" -3 "MISSING"
                       -2 "DON'T KNOW" -1 "REFUSED" 1 "Per week"
                       2 "Per month" 3 "Per year" ;
label define PHONE1    -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED"
                       1 "Telephone present" 2 "No telephone" ;
label define PHONE2    -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Telephone present" 2 "No telephone" ;
label define PERSON2   -3 "MISSING" -2 "DON'T KNOW" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define PHONE3    -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Telephone present" 2 "No telephone" ;
label define ENDYEAR   -3 "MISSING" ;
label define TOTTIME   -3 "MISSING" ;
label define BOXII     -3 "MISSING" -1 "REFUSED" 1 "Yes" 2 "No" ;
label define BOXIII    -3 "MISSING" 1 "Yes" 2 "No" ;
label define BOXIV     -5 "NOT APPLICABLE" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define BOXRECPT  -5 "NOT APPLICABLE" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define I11A      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define I11AA     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Medical"
                       2 "Non-medical" ;
label define I11AB     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define I11B      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define I11BA     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Medical"
                       2 "Non-medical" ;
label define I11BB     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define I11C      -5 "NOT APPLICABLE" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define I11CA     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Medical"
                       2 "Non-medical" ;
label define I11CB     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define I11D      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define I11DA     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Medical"
                       2 "Non-medical" ;
label define I11DB     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define I11E      -5 "NOT APPLICABLE" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define I11EA     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Medical"
                       2 "Non-medical" ;
label define I11EB     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define I11F      -5 "NOT APPLICABLE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSED" 1 "Yes" 2 "No" ;
label define I11FA     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Medical"
                       2 "Non-medical" ;
label define I11FB     -6 "LEGITIMATE SKIP" -3 "MISSING" -2 "DON'T KNOW"
                       1 "Yes" 2 "No" ;
label define I11G      -5 "NOT APPLICABLE" -3 "MISSING" -1 "REFUSED" 1 "Yes"
                       2 "No" ;
label define I11GA     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Medical"
                       2 "Non-medical" ;
label define I11GB     -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "Yes" 2 "No" ;
label define I11AC     -3 "MISSING" 1 "Positive" 2 "Negative" 3 "Refused"
                       4 "Not Possible" 6 "Invalid Specimen"
                       7 "Lost Specimen" ;
label define I11BC     -3 "MISSING" 1 "Positive" 2 "Negative" 3 "Refused"
                       4 "Not Possible" 6 "Invalid Specimen"
                       7 "Lost Specimen" ;
label define I11CC     -3 "MISSING" 1 "Positive" 2 "Negative" 3 "Refused"
                       4 "Not Possible" 6 "Invalid Specimen"
                       7 "Lost Specimen" ;
label define I11DC     -3 "MISSING" 1 "Positive" 2 "Negative" 3 "Refused"
                       4 "Not Possible" 6 "Invalid Specimen"
                       7 "Lost Specimen" ;
label define I11EC     -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define I11FC     -3 "MISSING" 1 "Positive" 2 "Negative" 3 "Refused"
                       4 "Not Possible" 6 "Invalid Specimen"
                       7 "Lost Specimen" ;
label define I11GC     -3 "MISSING" 1 "Positive" 2 "Negative" 3 "Refused"
                       4 "Not Possible" 6 "Invalid Specimen"
                       7 "Lost Specimen" ;
label define D6A_1     -3 "MISSING" -2 "DON'T KNOW" ;
label define INHAL     -3 "MISSING"
                       0 "Never used (or used less than 5 times)"
                       1 "Used as main drug at time entering tx"
                       2 "Used as main drug at other time"
                       3 "Used but not as main drug" ;
label define ALCOHOL   -3 "MISSING"
                       0 "Never used (or used less than 5 times)"
                       1 "Used as main drug at time entering tx"
                       2 "Used as main drug at other time"
                       3 "Used but not as main drug" ;
label define MARIJUAN  -3 "MISSING"
                       0 "Never used (or used less than 5 times)"
                       1 "Used as main drug at time entering tx"
                       2 "Used as main drug at other time"
                       3 "Used but not as main drug" ;
label define CRACK     -3 "MISSING"
                       0 "Never used (or used less than 5 times)"
                       1 "Used as main drug at time entering tx"
                       2 "Used as main drug at other time"
                       3 "Used but not as main drug" ;
label define COCAINE   -3 "MISSING"
                       0 "Never used (or used less than 5 times)"
                       1 "Used as main drug at time entering tx"
                       2 "Used as main drug at other time"
                       3 "Used but not as main drug" ;
label define PCP       -3 "MISSING"
                       0 "Never used (or used less than 5 times)"
                       1 "Used as main drug at time entering tx"
                       2 "Used as main drug at other time"
                       3 "Used but not as main drug" ;
label define HALLUCIN  -3 "MISSING"
                       0 "Never used (or used less than 5 times)"
                       1 "Used as main drug at time entering tx"
                       2 "Used as main drug at other time"
                       3 "Used but not as main drug" ;
label define HEROIN    -3 "MISSING"
                       0 "Never used (or used less than 5 times)"
                       1 "Used as main drug at time entering tx"
                       2 "Used as main drug at other time"
                       3 "Used but not as main drug" ;
label define ILLMETH   -3 "MISSING"
                       0 "Never used (or used less than 5 times)"
                       1 "Used as main drug at time entering tx"
                       2 "Used as main drug at other time"
                       3 "Used but not as main drug" ;
label define NARC      -3 "MISSING"
                       0 "Never used (or used less than 5 times)"
                       1 "Used as main drug at time entering tx"
                       2 "Used as main drug at other time"
                       3 "Used but not as main drug" ;
label define METHAMPH  -3 "MISSING"
                       0 "Never used (or used less than 5 times)"
                       1 "Used as main drug at time entering tx"
                       2 "Used as main drug at other time"
                       3 "Used but not as main drug" ;
label define DOWNERS   -3 "MISSING"
                       0 "Never used (or used less than 5 times)"
                       1 "Used as main drug at time entering tx"
                       2 "Used as main drug at other time"
                       3 "Used but not as main drug" ;
label define OTHDRUG   -3 "MISSING"
                       0 "Never used (or used less than 5 times)"
                       1 "Used as main drug at time entering tx"
                       2 "Used as main drug at other time"
                       3 "Used but not as main drug" ;
label define AGEFINH   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define AGEFALC   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define AGEFMAR   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define AGFCRK    -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define AGEFCOC   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define AGEFPCP   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define AGEFHAL   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define AGEFHER   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define AGEFMTH   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define AGEFNAR   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define AGEFAMP   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define AGEFDWN   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define AGEFOTH   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define USBINH    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USBALC    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USBMAR    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USBCRK    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USBCOC    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USBPCP    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USBHAL    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USBHER    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USBMTH    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USBNAR    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USBAMP    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USBDWN    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USBOTH    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USBDINH   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USBDALC   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USBDMAR   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USBDCRK   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USBDCOC   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USBDPCP   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USBDHAL   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USBDHER   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USBDMTH   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USBDNAR   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USBDAMP   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USBDDWN   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USBDOTH   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USAINH    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USAALC    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USAMAR    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USACRK    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USACOC    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USAPCP    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USAHAL    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USAHER    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USAMTH    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USANAR    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USAAMP    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USADWN    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USAOTH    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USADINH   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USADALC   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USADMAR   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USADCRK   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USADCOC   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USADPCP   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USADHAL   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USADHER   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USADMTH   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USADNAR   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USADAMP   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USADDWN   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USADOTH   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USYINH    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USYALC    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USYMAR    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USYCRK    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USYCOC    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USYPCP    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USYHAL    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USYHER    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USYMTH    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USYNAR    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USYAMP    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USYDWN    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USYOTH    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USYDINH   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       4 "11 to 20 days/month" 5 "21 to 31 days/month"
                       6 "Every day" ;
label define USYDALC   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USYDMAR   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USYDCRK   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USYDCOC   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USYDPCP   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 5 "21 to 31 days/month" ;
label define USYDHAL   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" ;
label define USYDHER   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USYDMTH   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       6 "Every day" ;
label define USYDNAR   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USYDAMP   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USYDDWN   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USYDOTH   -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USNINH    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USNALC    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USNMAR    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USNCRK    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USNCOC    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USNPCP    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USNHAL    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USNHER    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USNMTH    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USNNAR    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USNAMP    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USNDWN    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USNOTH    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USNMINH   -6 "LEGITIMATE SKIP" -3 "MISSING" 2 "2 to 3 months"
                       3 "4 to 5 months" ;
label define USNMALC   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "1 month"
                       2 "2 to 3 months" 3 "4 to 5 months" 4 "6 to 8 months"
                       5 "9 or more months" ;
label define USNMMAR   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "1 month"
                       2 "2 to 3 months" 3 "4 to 5 months" 4 "6 to 8 months"
                       5 "9 or more months" ;
label define USNMCRK   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "1 month"
                       2 "2 to 3 months" 3 "4 to 5 months" 4 "6 to 8 months"
                       5 "9 or more months" ;
label define USNMCOC   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "1 month"
                       2 "2 to 3 months" 3 "4 to 5 months" 4 "6 to 8 months"
                       5 "9 or more months" ;
label define USNMPCP   -6 "LEGITIMATE SKIP" -3 "MISSING" ;
label define USNMHAL   -6 "LEGITIMATE SKIP" -3 "MISSING" 2 "2 to 3 months"
                       3 "4 to 5 months" 4 "6 to 8 months"
                       5 "9 or more months" ;
label define USNMHER   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "1 month"
                       2 "2 to 3 months" 3 "4 to 5 months" 4 "6 to 8 months"
                       5 "9 or more months" ;
label define USNMMTH   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "1 month"
                       2 "2 to 3 months" 4 "6 to 8 months" ;
label define USNMNAR   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "1 month"
                       2 "2 to 3 months" 3 "4 to 5 months" 4 "6 to 8 months"
                       5 "9 or more months" ;
label define USNMAMP   -6 "LEGITIMATE SKIP" -3 "MISSING" 2 "2 to 3 months"
                       3 "4 to 5 months" 4 "6 to 8 months"
                       5 "9 or more months" ;
label define USNMDWN   -6 "LEGITIMATE SKIP" -3 "MISSING" 2 "2 to 3 months"
                       3 "4 to 5 months" 4 "6 to 8 months"
                       5 "9 or more months" ;
label define USNMOTH   -6 "LEGITIMATE SKIP" -3 "MISSING" 1 "1 month"
                       2 "2 to 3 months" 3 "4 to 5 months" 4 "6 to 8 months"
                       5 "9 or more months" ;
label define USMINH    -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month" 6 "Every day" ;
label define USMALC    -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USMMAR    -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USMCRK    -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USMCOC    -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USMPCP    -3 "MISSING" 0 "Did not use five times or more"
                       2 "2 to 5 days/month" 4 "11 to 20 days/month" ;
label define USMHAL    -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 5 "21 to 31 days/month" ;
label define USMHER    -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USMMTH    -3 "MISSING" 0 "Did not use five times or more"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       6 "Every day" ;
label define USMNAR    -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USMAMP    -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USMDWN    -3 "MISSING" 0 "Did not use five times or more"
                       1 "1 day/month" 2 "2 to 5 days/month"
                       3 "6 to 10 days/month" 4 "11 to 20 days/month"
                       5 "21 to 31 days/month" 6 "Every day" ;
label define USMOTH    -3 "MISSING" 0 "Did not use five times or more"
                       2 "2 to 5 days/month" 3 "6 to 10 days/month"
                       4 "11 to 20 days/month" 6 "Every day" ;
label define USBSEC    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USASEC    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USBANY    -3 "MISSING" 0 "No" 1 "Yes" ;
label define USAANY    -3 "MISSING" 0 "No" 1 "Yes" ;
label define TRTYPE    -3 "MISSING" 1 "Inpatient" 2 "Residential"
                       3 "Outpatient Methadone Maintenance"
                       4 "Outpatient Drug-Free" ;
label define LOS       -3 "MISSING" 1825 "1825+" ;
label define LOSCAT    -3 "MISSING" 1 "Less than 1 week"
                       2 "1 week to less than 1 month" 3 "1 to 5 months"
                       4 "6 months or more" ;
label define RACE      -3 "MISSING" 1 "White (non-Hispanic)"
                       2 "Black (non-Hispanic)" 3 "Hispanic" 4 "Other" ;
label define DISAGE    -3 "MISSING" 75 "75+" ;
label define DISAGE2   -3 "MISSING" 1 "Less than 18" 2 "18 to 29"
                       3 "30 to 39" 4 "40 or older" ;
label define PRETRT    -3 "MISSING" 1 "0" 2 "1 to 2" 3 "3 or more" ;
label define COMPTRT   -3 "MISSING" 1 "Yes" 2 "No" ;
label define AFTTRT    -3 "MISSING" 1 "Yes" 2 "No" ;
label define HELPTRT   -3 "MISSING" 1 "Very helpful" 2 "Somewhat/not helpful" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace CLIENTID = . if (CLIENTID <= -1 )
replace FAC_ID = . if (FAC_ID <= -1 )
replace MODE = . if (MODE <= -1 )
replace WT1 = . if (WT1 <= -1.0000 )
replace WT2 = . if (WT2 <= -1.0000 )
replace WT3 = . if (WT3 <= -1.0000 )
replace A1 = . if (A1 <= -1 )
replace A3 = . if (A3 <= -1 )
replace A4 = . if (A4 <= -1 )
replace A4A_1 = . if (A4A_1 <= -1 )
replace A4A_2 = . if (A4A_2 <= -1 )
replace A4A_3 = . if (A4A_3 <= -1 )
replace A4A_4 = . if (A4A_4 <= -1 )
replace A5 = . if (A5 <= -1 )
replace A6 = . if (A6 <= -1 )
replace A7 = . if (A7 <= -1 )
replace A8 = . if (A8 <= -1 )
replace A8A_1 = . if (A8A_1 <= -1 )
replace A8A_2 = . if (A8A_2 <= -1 )
replace A8A_3 = . if (A8A_3 <= -1 )
replace A8A_4 = . if (A8A_4 <= -1 )
replace A9 = . if (A9 <= -1 )
replace A9A = . if (A9A <= -1 )
replace A10 = . if (A10 <= -1 )
replace A11 = . if (A11 <= -1 )
replace B1 = . if (B1 <= -1 )
replace B2 = . if (B2 <= -1 )
replace B2B = . if (B2B <= -1 )
replace B4 = . if (B4 <= -1 )
replace B5 = . if (B5 <= -1 )
replace B5A = . if (B5A <= -1 )
replace B6_1 = . if (B6_1 <= -1 )
replace B6_2 = . if (B6_2 <= -1 )
replace B6_3 = . if (B6_3 <= -1 )
replace B6_4 = . if (B6_4 <= -1 )
replace B6_5 = . if (B6_5 <= -1 )
replace B6_6 = . if (B6_6 <= -1 )
replace B6_7 = . if (B6_7 <= -1 )
replace B6_8 = . if (B6_8 <= -1 )
replace B6_9 = . if (B6_9 <= -1 )
replace B6_10 = . if (B6_10 <= -1 )
replace B6_11 = . if (B6_11 <= -1 )
replace B6_12 = . if (B6_12 <= -1 )
replace B6_13 = . if (B6_13 <= -1 )
replace B6_14 = . if (B6_14 <= -1 )
replace B7_1 = . if (B7_1 <= -1 )
replace B7_2 = . if (B7_2 <= -1 )
replace B7_3 = . if (B7_3 <= -1 )
replace B7_4 = . if (B7_4 <= -1 )
replace B7_5 = . if (B7_5 <= -1 )
replace B8A = . if (B8A <= -1 )
replace B8B = . if (B8B <= -1 )
replace B8C = . if (B8C <= -1 )
replace B8D = . if (B8D <= -1 )
replace B8E = . if (B8E <= -1 )
replace B8F = . if (B8F <= -1 )
replace B8G = . if (B8G <= -1 )
replace B9A = . if (B9A <= -1 )
replace B9B = . if (B9B <= -1 )
replace B9C = . if (B9C <= -1 )
replace B9D = . if (B9D <= -1 )
replace B9E = . if (B9E <= -1 )
replace B9F = . if (B9F <= -1 )
replace B10 = . if (B10 <= -1 )
replace B11 = . if (B11 <= -1 )
replace B11A = . if (B11A <= -1 )
replace B12 = . if (B12 <= -1 )
replace B12A_1 = . if (B12A_1 <= -1 )
replace B12A_2 = . if (B12A_2 <= -1 )
replace B12A_3 = . if (B12A_3 <= -1 )
replace B12A_4 = . if (B12A_4 <= -1 )
replace B12A_5 = . if (B12A_5 <= -1 )
replace B12A_6 = . if (B12A_6 <= -1 )
replace B12A_7 = . if (B12A_7 <= -1 )
replace B12A_8 = . if (B12A_8 <= -1 )
replace B12A_9 = . if (B12A_9 <= -1 )
replace B12A_10 = . if (B12A_10 <= -1 )
replace B12A_11 = . if (B12A_11 <= -1 )
replace B12A_12 = . if (B12A_12 <= -1 )
replace B12A_13 = . if (B12A_13 <= -1 )
replace B12B = . if (B12B <= -1 )
replace B12C = . if (B12C <= -1 )
replace B13 = . if (B13 <= -1 )
replace B14 = . if (B14 <= -1 )
replace B15 = . if (B15 <= -1 )
replace B16 = . if (B16 <= -1 )
replace B16A = . if (B16A <= -1 )
replace B16B = . if (B16B <= -1 )
replace B17 = . if (B17 <= -1 )
replace B18 = . if (B18 <= -1 )
replace B18AA = . if (B18AA <= -1 )
replace B18AB = . if (B18AB <= -1 )
replace B18AC = . if (B18AC <= -1 )
replace B19A = . if (B19A <= -1 )
replace B19B = . if (B19B <= -1 )
replace B19C = . if (B19C <= -1 )
replace B19D = . if (B19D <= -1 )
replace B19E = . if (B19E <= -1 )
replace B19F = . if (B19F <= -1 )
replace B19G = . if (B19G <= -1 )
replace B19H = . if (B19H <= -1 )
replace B19I = . if (B19I <= -1 )
replace B20 = . if (B20 <= -1 )
replace BOX20A = . if (BOX20A <= -1 )
replace B21CODE = . if (B21CODE <= -1 )
replace B21BYR = . if (B21BYR <= -1 )
replace B21C = . if (B21C <= -1 )
replace B21D = . if (B21D <= -1 )
replace B21D2 = . if (B21D2 <= -1 )
replace B21ECOD = . if (B21ECOD <= -1 )
replace B21GY = . if (B21GY <= -1 )
replace B21H = . if (B21H <= -1 )
replace B22 = . if (B22 <= -1 )
replace B23A = . if (B23A <= -1 )
replace B23B = . if (B23B <= -1 )
replace B23C = . if (B23C <= -1 )
replace B23D = . if (B23D <= -1 )
replace B23E = . if (B23E <= -1 )
replace B24A = . if (B24A <= -1 )
replace B24B = . if (B24B <= -1 )
replace B24C = . if (B24C <= -1 )
replace B25 = . if (B25 <= -1 )
replace B25AA = . if (B25AA <= -1 )
replace B25AB = . if (B25AB <= -1 )
replace B25AC = . if (B25AC <= -1 )
replace B26 = . if (B26 <= -1 )
replace B26A = . if (B26A <= -1 )
replace B27CODE = . if (B27CODE <= -1 )
replace B29A = . if (B29A <= -1 )
replace B29B = . if (B29B <= -1 )
replace B29C_1 = . if (B29C_1 <= -1 )
replace B29C_2 = . if (B29C_2 <= -1 )
replace B29C_3 = . if (B29C_3 <= -1 )
replace B29C_4 = . if (B29C_4 <= -1 )
replace B29C_5 = . if (B29C_5 <= -1 )
replace B29C_6 = . if (B29C_6 <= -1 )
replace B29C_7 = . if (B29C_7 <= -1 )
replace B29C_8 = . if (B29C_8 <= -1 )
replace B29C_9 = . if (B29C_9 <= -1 )
replace B29C_10 = . if (B29C_10 <= -1 )
replace B29C_11 = . if (B29C_11 <= -1 )
replace B29C_12 = . if (B29C_12 <= -1 )
replace B29C_13 = . if (B29C_13 <= -1 )
replace B29C_14 = . if (B29C_14 <= -1 )
replace B30A = . if (B30A <= -1 )
replace B30B = . if (B30B <= -1 )
replace B30C_1 = . if (B30C_1 <= -1 )
replace B30C_2 = . if (B30C_2 <= -1 )
replace B30C_3 = . if (B30C_3 <= -1 )
replace B30C_4 = . if (B30C_4 <= -1 )
replace B30C_5 = . if (B30C_5 <= -1 )
replace B30C_6 = . if (B30C_6 <= -1 )
replace B30C_7 = . if (B30C_7 <= -1 )
replace B30C_8 = . if (B30C_8 <= -1 )
replace B30C_9 = . if (B30C_9 <= -1 )
replace B30C_10 = . if (B30C_10 <= -1 )
replace B30C_11 = . if (B30C_11 <= -1 )
replace B30C_12 = . if (B30C_12 <= -1 )
replace B30C_13 = . if (B30C_13 <= -1 )
replace B30C_14 = . if (B30C_14 <= -1 )
replace B31A = . if (B31A <= -1 )
replace B31B = . if (B31B <= -1 )
replace B31C_1 = . if (B31C_1 <= -1 )
replace B31C_2 = . if (B31C_2 <= -1 )
replace B31C_3 = . if (B31C_3 <= -1 )
replace B31C_4 = . if (B31C_4 <= -1 )
replace B31C_5 = . if (B31C_5 <= -1 )
replace B31C_6 = . if (B31C_6 <= -1 )
replace B31C_7 = . if (B31C_7 <= -1 )
replace B31C_8 = . if (B31C_8 <= -1 )
replace B31C_9 = . if (B31C_9 <= -1 )
replace B31C_10 = . if (B31C_10 <= -1 )
replace B31C_11 = . if (B31C_11 <= -1 )
replace B31C_12 = . if (B31C_12 <= -1 )
replace B31C_13 = . if (B31C_13 <= -1 )
replace B31C_14 = . if (B31C_14 <= -1 )
replace B32A = . if (B32A <= -1 )
replace B32B = . if (B32B <= -1 )
replace B32C_1 = . if (B32C_1 <= -1 )
replace B32C_2 = . if (B32C_2 <= -1 )
replace B32C_3 = . if (B32C_3 <= -1 )
replace B32C_4 = . if (B32C_4 <= -1 )
replace B32C_5 = . if (B32C_5 <= -1 )
replace B32C_6 = . if (B32C_6 <= -1 )
replace B32C_7 = . if (B32C_7 <= -1 )
replace B32C_8 = . if (B32C_8 <= -1 )
replace B32C_9 = . if (B32C_9 <= -1 )
replace B32C_10 = . if (B32C_10 <= -1 )
replace B32C_11 = . if (B32C_11 <= -1 )
replace B32C_12 = . if (B32C_12 <= -1 )
replace B32C_13 = . if (B32C_13 <= -1 )
replace B32C_14 = . if (B32C_14 <= -1 )
replace B33A = . if (B33A <= -1 )
replace B33B = . if (B33B <= -1 )
replace B33C_1 = . if (B33C_1 <= -1 )
replace B33C_2 = . if (B33C_2 <= -1 )
replace B33C_3 = . if (B33C_3 <= -1 )
replace B33C_4 = . if (B33C_4 <= -1 )
replace B33C_5 = . if (B33C_5 <= -1 )
replace B33C_6 = . if (B33C_6 <= -1 )
replace B33C_7 = . if (B33C_7 <= -1 )
replace B33C_8 = . if (B33C_8 <= -1 )
replace B33C_9 = . if (B33C_9 <= -1 )
replace B33C_10 = . if (B33C_10 <= -1 )
replace B33C_11 = . if (B33C_11 <= -1 )
replace B33C_12 = . if (B33C_12 <= -1 )
replace B33C_13 = . if (B33C_13 <= -1 )
replace B33C_14 = . if (B33C_14 <= -1 )
replace B34A = . if (B34A <= -1 )
replace B34B = . if (B34B <= -1 )
replace B34C = . if (B34C <= -1 )
replace B35 = . if (B35 <= -1 )
replace B35AA = . if (B35AA <= -1 )
replace B35AB = . if (B35AB <= -1 )
replace B35AC = . if (B35AC <= -1 )
replace B36 = . if (B36 <= -1 )
replace B41_1 = . if (B41_1 <= -1 )
replace B41_2 = . if (B41_2 <= -1 )
replace B41_3 = . if (B41_3 <= -1 )
replace B41_4 = . if (B41_4 <= -1 )
replace B41_5 = . if (B41_5 <= -1 )
replace B41_6 = . if (B41_6 <= -1 )
replace B41_7 = . if (B41_7 <= -1 )
replace B41_8 = . if (B41_8 <= -1 )
replace B41_9 = . if (B41_9 <= -1 )
replace B41_10 = . if (B41_10 <= -1 )
replace B41_11 = . if (B41_11 <= -1 )
replace B41_12 = . if (B41_12 <= -1 )
replace B41_13 = . if (B41_13 <= -1 )
replace B42 = . if (B42 <= -1 )
replace B43 = . if (B43 <= -1 )
replace B44 = . if (B44 <= -1 )
replace B44A = . if (B44A <= -1 )
replace B45 = . if (B45 <= -1 )
replace B46 = . if (B46 <= -1 )
replace B46AA = . if (B46AA <= -1 )
replace B46AB = . if (B46AB <= -1 )
replace B46AC = . if (B46AC <= -1 )
replace B47A = . if (B47A <= -1 )
replace B47B = . if (B47B <= -1 )
replace B47C = . if (B47C <= -1 )
replace B47D = . if (B47D <= -1 )
replace B47E = . if (B47E <= -1 )
replace B47F = . if (B47F <= -1 )
replace B47G = . if (B47G <= -1 )
replace B47H = . if (B47H <= -1 )
replace B47I = . if (B47I <= -1 )
replace B48 = . if (B48 <= -1 )
replace C1AINHAL = . if (C1AINHAL <= -1 )
replace C1AALCOH = . if (C1AALCOH <= -1 )
replace C1AMARIJ = . if (C1AMARIJ <= -1 )
replace C1ACRACK = . if (C1ACRACK <= -1 )
replace C1ACOCAI = . if (C1ACOCAI <= -1 )
replace C1APCP = . if (C1APCP <= -1 )
replace C1AHALLU = . if (C1AHALLU <= -1 )
replace C1AHEROI = . if (C1AHEROI <= -1 )
replace C1AMTHDO = . if (C1AMTHDO <= -1 )
replace C1AONARC = . if (C1AONARC <= -1 )
replace C1AMETHA = . if (C1AMETHA <= -1 )
replace C1ADOWNR = . if (C1ADOWNR <= -1 )
replace C1AODRUG = . if (C1AODRUG <= -1 )
replace C2INHAL = . if (C2INHAL <= -1 )
replace C3INHAL = . if (C3INHAL <= -1 )
replace C3AINHAL = . if (C3AINHAL <= -1 )
replace C4INHAL = . if (C4INHAL <= -1 )
replace C5INHAL = . if (C5INHAL <= -1 )
replace C6INHAL = . if (C6INHAL <= -1 )
replace C7INHAL = . if (C7INHAL <= -1 )
replace C8INHAL = . if (C8INHAL <= -1 )
replace C8AINHAL = . if (C8AINHAL <= -1 )
replace C9INHAL = . if (C9INHAL <= -1 )
replace C2ALCOH = . if (C2ALCOH <= -1 )
replace C3ALCOH = . if (C3ALCOH <= -1 )
replace C3AALCOH = . if (C3AALCOH <= -1 )
replace C4ALCOH = . if (C4ALCOH <= -1 )
replace C5ALCOH = . if (C5ALCOH <= -1 )
replace C6ALCOH = . if (C6ALCOH <= -1 )
replace C7ALCOH = . if (C7ALCOH <= -1 )
replace C8ALCOH = . if (C8ALCOH <= -1 )
replace C8AALCOH = . if (C8AALCOH <= -1 )
replace C9ALCOH = . if (C9ALCOH <= -1 )
replace C2MARIJ = . if (C2MARIJ <= -1 )
replace C3MARIJ = . if (C3MARIJ <= -1 )
replace C3AMARIJ = . if (C3AMARIJ <= -1 )
replace C4MARIJ = . if (C4MARIJ <= -1 )
replace C5MARIJ = . if (C5MARIJ <= -1 )
replace C6MARIJ = . if (C6MARIJ <= -1 )
replace C7MARIJ = . if (C7MARIJ <= -1 )
replace C8MARIJ = . if (C8MARIJ <= -1 )
replace C8AMARIJ = . if (C8AMARIJ <= -1 )
replace C9MARIJ = . if (C9MARIJ <= -1 )
replace C2CRACK = . if (C2CRACK <= -1 )
replace C3CRACK = . if (C3CRACK <= -1 )
replace C3ACRACK = . if (C3ACRACK <= -1 )
replace C4CRACK = . if (C4CRACK <= -1 )
replace C5CRACK = . if (C5CRACK <= -1 )
replace C6CRACK = . if (C6CRACK <= -1 )
replace C7CRACK = . if (C7CRACK <= -1 )
replace C8CRACK = . if (C8CRACK <= -1 )
replace C8ACRACK = . if (C8ACRACK <= -1 )
replace C9CRACK = . if (C9CRACK <= -1 )
replace C2COCAI = . if (C2COCAI <= -1 )
replace C3COCAI = . if (C3COCAI <= -1 )
replace C3ACOCAI = . if (C3ACOCAI <= -1 )
replace C4COCAI = . if (C4COCAI <= -1 )
replace C5COCAI = . if (C5COCAI <= -1 )
replace C6COCAI = . if (C6COCAI <= -1 )
replace C7COCAI = . if (C7COCAI <= -1 )
replace C8COCAI = . if (C8COCAI <= -1 )
replace C8ACOCAI = . if (C8ACOCAI <= -1 )
replace C9COCAI = . if (C9COCAI <= -1 )
replace C2PCP = . if (C2PCP <= -1 )
replace C3PCP = . if (C3PCP <= -1 )
replace C3APCP = . if (C3APCP <= -1 )
replace C4PCP = . if (C4PCP <= -1 )
replace C5PCP = . if (C5PCP <= -1 )
replace C6PCP = . if (C6PCP <= -1 )
replace C7PCP = . if (C7PCP <= -1 )
replace C8PCP = . if (C8PCP <= -1 )
replace C8APCP = . if (C8APCP <= -1 )
replace C9PCP = . if (C9PCP <= -1 )
replace C2HALLU = . if (C2HALLU <= -1 )
replace C3HALLU = . if (C3HALLU <= -1 )
replace C3AHALLU = . if (C3AHALLU <= -1 )
replace C4HALLU = . if (C4HALLU <= -1 )
replace C5HALLU = . if (C5HALLU <= -1 )
replace C6HALLU = . if (C6HALLU <= -1 )
replace C7HALLU = . if (C7HALLU <= -1 )
replace C8HALLU = . if (C8HALLU <= -1 )
replace C8AHALLU = . if (C8AHALLU <= -1 )
replace C9HALLU = . if (C9HALLU <= -1 )
replace C2HEROI = . if (C2HEROI <= -1 )
replace C3HEROI = . if (C3HEROI <= -1 )
replace C3AHEROI = . if (C3AHEROI <= -1 )
replace C4HEROI = . if (C4HEROI <= -1 )
replace C5HEROI = . if (C5HEROI <= -1 )
replace C6HEROI = . if (C6HEROI <= -1 )
replace C7HEROI = . if (C7HEROI <= -1 )
replace C8HEROI = . if (C8HEROI <= -1 )
replace C8AHEROI = . if (C8AHEROI <= -1 )
replace C9HEROI = . if (C9HEROI <= -1 )
replace C2MTHDO = . if (C2MTHDO <= -1 )
replace C3MTHDO = . if (C3MTHDO <= -1 )
replace C3AMTHDO = . if (C3AMTHDO <= -1 )
replace C4MTHDO = . if (C4MTHDO <= -1 )
replace C5MTHDO = . if (C5MTHDO <= -1 )
replace C6MTHDO = . if (C6MTHDO <= -1 )
replace C7MTHDO = . if (C7MTHDO <= -1 )
replace C8MTHDO = . if (C8MTHDO <= -1 )
replace C8AMTHDO = . if (C8AMTHDO <= -1 )
replace C9MTHDO = . if (C9MTHDO <= -1 )
replace C2ONARC = . if (C2ONARC <= -1 )
replace C3ONARC = . if (C3ONARC <= -1 )
replace C3AONARC = . if (C3AONARC <= -1 )
replace C4ONARC = . if (C4ONARC <= -1 )
replace C5ONARC = . if (C5ONARC <= -1 )
replace C6ONARC = . if (C6ONARC <= -1 )
replace C7ONARC = . if (C7ONARC <= -1 )
replace C8ONARC = . if (C8ONARC <= -1 )
replace C8AONARC = . if (C8AONARC <= -1 )
replace C9ONARC = . if (C9ONARC <= -1 )
replace C2METHA = . if (C2METHA <= -1 )
replace C3METHA = . if (C3METHA <= -1 )
replace C3AMETHA = . if (C3AMETHA <= -1 )
replace C4METHA = . if (C4METHA <= -1 )
replace C5METHA = . if (C5METHA <= -1 )
replace C6METHA = . if (C6METHA <= -1 )
replace C7METHA = . if (C7METHA <= -1 )
replace C8METHA = . if (C8METHA <= -1 )
replace C8AMETHA = . if (C8AMETHA <= -1 )
replace C9METHA = . if (C9METHA <= -1 )
replace C2DOWNR = . if (C2DOWNR <= -1 )
replace C3DOWNR = . if (C3DOWNR <= -1 )
replace C3ADOWNR = . if (C3ADOWNR <= -1 )
replace C4DOWNR = . if (C4DOWNR <= -1 )
replace C5DOWNR = . if (C5DOWNR <= -1 )
replace C6DOWNR = . if (C6DOWNR <= -1 )
replace C7DOWNR = . if (C7DOWNR <= -1 )
replace C8DOWNR = . if (C8DOWNR <= -1 )
replace C8ADOWNR = . if (C8ADOWNR <= -1 )
replace C9DOWNR = . if (C9DOWNR <= -1 )
replace C2ODRUG = . if (C2ODRUG <= -1 )
replace C3ODRUG = . if (C3ODRUG <= -1 )
replace C3AODRUG = . if (C3AODRUG <= -1 )
replace C4ODRUG = . if (C4ODRUG <= -1 )
replace C5ODRUG = . if (C5ODRUG <= -1 )
replace C6ODRUG = . if (C6ODRUG <= -1 )
replace C7ODRUG = . if (C7ODRUG <= -1 )
replace C8ODRUG = . if (C8ODRUG <= -1 )
replace C8AODRUG = . if (C8AODRUG <= -1 )
replace C9ODRUG = . if (C9ODRUG <= -1 )
replace C10 = . if (C10 <= -1 )
replace C11 = . if (C11 <= -1 )
replace C12_1 = . if (C12_1 <= -1 )
replace C13_1 = . if (C13_1 <= -1.0 )
replace C13_1A = . if (C13_1A <= -1 )
replace C12_2 = . if (C12_2 <= -1 )
replace C13_2 = . if (C13_2 <= -1.0 )
replace C13_2A = . if (C13_2A <= -1 )
replace C12_3 = . if (C12_3 <= -1 )
replace C13_3 = . if (C13_3 <= -1.0 )
replace C13_3A = . if (C13_3A <= -1 )
replace C15INHA = . if (C15INHA <= -1 )
replace C15ALCO = . if (C15ALCO <= -1 )
replace C15MARI = . if (C15MARI <= -1 )
replace C15CRCK = . if (C15CRCK <= -1 )
replace C15COCA = . if (C15COCA <= -1 )
replace C15PCP = . if (C15PCP <= -1 )
replace C15HALU = . if (C15HALU <= -1 )
replace C15HERO = . if (C15HERO <= -1 )
replace C15MTDO = . if (C15MTDO <= -1 )
replace C15ONRC = . if (C15ONRC <= -1 )
replace C15METH = . if (C15METH <= -1 )
replace C15DOWN = . if (C15DOWN <= -1 )
replace C15OTHR = . if (C15OTHR <= -1 )
replace C16INHA = . if (C16INHA <= -1 )
replace C17INHA = . if (C17INHA <= -1 )
replace C18INHA = . if (C18INHA <= -1 )
replace C18AINHA = . if (C18AINHA <= -1 )
replace C19INHA = . if (C19INHA <= -1 )
replace C19AINHA = . if (C19AINHA <= -1 )
replace C20INHA = . if (C20INHA <= -1 )
replace C20AINHA = . if (C20AINHA <= -1 )
replace C21INHA = . if (C21INHA <= -1 )
replace C16ALCO = . if (C16ALCO <= -1 )
replace C17ALCO = . if (C17ALCO <= -1 )
replace C18ALCO = . if (C18ALCO <= -1 )
replace C18AALCO = . if (C18AALCO <= -1 )
replace C19ALCO = . if (C19ALCO <= -1 )
replace C19AALCO = . if (C19AALCO <= -1 )
replace C20ALCO = . if (C20ALCO <= -1 )
replace C20AALCO = . if (C20AALCO <= -1 )
replace C21ALCO = . if (C21ALCO <= -1 )
replace C16MARI = . if (C16MARI <= -1 )
replace C17MARI = . if (C17MARI <= -1 )
replace C18MARI = . if (C18MARI <= -1 )
replace C18AMARI = . if (C18AMARI <= -1 )
replace C19MARI = . if (C19MARI <= -1 )
replace C19AMARI = . if (C19AMARI <= -1 )
replace C20MARI = . if (C20MARI <= -1 )
replace C20AMARI = . if (C20AMARI <= -1 )
replace C21MARI = . if (C21MARI <= -1 )
replace C16CRCK = . if (C16CRCK <= -1 )
replace C17CRCK = . if (C17CRCK <= -1 )
replace C18CRCK = . if (C18CRCK <= -1 )
replace C18ACRCK = . if (C18ACRCK <= -1 )
replace C19CRCK = . if (C19CRCK <= -1 )
replace C19ACRCK = . if (C19ACRCK <= -1 )
replace C20CRCK = . if (C20CRCK <= -1 )
replace C20ACRCK = . if (C20ACRCK <= -1 )
replace C21CRCK = . if (C21CRCK <= -1 )
replace C16COCA = . if (C16COCA <= -1 )
replace C17COCA = . if (C17COCA <= -1 )
replace C18COCA = . if (C18COCA <= -1 )
replace C18ACOCA = . if (C18ACOCA <= -1 )
replace C19COCA = . if (C19COCA <= -1 )
replace C19ACOCA = . if (C19ACOCA <= -1 )
replace C20COCA = . if (C20COCA <= -1 )
replace C20ACOCA = . if (C20ACOCA <= -1 )
replace C21COCA = . if (C21COCA <= -1 )
replace C16PCP = . if (C16PCP <= -1 )
replace C17PCP = . if (C17PCP <= -1 )
replace C18PCP = . if (C18PCP <= -1 )
replace C18APCP = . if (C18APCP <= -1 )
replace C19PCP = . if (C19PCP <= -1 )
replace C19APCP = . if (C19APCP <= -1 )
replace C20PCP = . if (C20PCP <= -1 )
replace C20APCP = . if (C20APCP <= -1 )
replace C21PCP = . if (C21PCP <= -1 )
replace C16HALU = . if (C16HALU <= -1 )
replace C17HALU = . if (C17HALU <= -1 )
replace C18HALU = . if (C18HALU <= -1 )
replace C18AHALU = . if (C18AHALU <= -1 )
replace C19HALU = . if (C19HALU <= -1 )
replace C19AHALU = . if (C19AHALU <= -1 )
replace C20HALU = . if (C20HALU <= -1 )
replace C20AHALU = . if (C20AHALU <= -1 )
replace C21HALU = . if (C21HALU <= -1 )
replace C16HERO = . if (C16HERO <= -1 )
replace C17HERO = . if (C17HERO <= -1 )
replace C18HERO = . if (C18HERO <= -1 )
replace C18AHERO = . if (C18AHERO <= -1 )
replace C19HERO = . if (C19HERO <= -1 )
replace C19AHERO = . if (C19AHERO <= -1 )
replace C20HERO = . if (C20HERO <= -1 )
replace C20AHERO = . if (C20AHERO <= -1 )
replace C21HERO = . if (C21HERO <= -1 )
replace C16MTDO = . if (C16MTDO <= -1 )
replace C17MTDO = . if (C17MTDO <= -1 )
replace C18MTDO = . if (C18MTDO <= -1 )
replace C18AMTDO = . if (C18AMTDO <= -1 )
replace C19MTDO = . if (C19MTDO <= -1 )
replace C19AMTDO = . if (C19AMTDO <= -1 )
replace C20MTDO = . if (C20MTDO <= -1 )
replace C20AMTDO = . if (C20AMTDO <= -1 )
replace C21MTDO = . if (C21MTDO <= -1 )
replace C16ONRC = . if (C16ONRC <= -1 )
replace C17ONRC = . if (C17ONRC <= -1 )
replace C18ONRC = . if (C18ONRC <= -1 )
replace C18AONRC = . if (C18AONRC <= -1 )
replace C19ONRC = . if (C19ONRC <= -1 )
replace C19AONRC = . if (C19AONRC <= -1 )
replace C20ONRC = . if (C20ONRC <= -1 )
replace C20AONRC = . if (C20AONRC <= -1 )
replace C21ONRC = . if (C21ONRC <= -1 )
replace C16METH = . if (C16METH <= -1 )
replace C17METH = . if (C17METH <= -1 )
replace C18METH = . if (C18METH <= -1 )
replace C18AMETH = . if (C18AMETH <= -1 )
replace C19METH = . if (C19METH <= -1 )
replace C19AMETH = . if (C19AMETH <= -1 )
replace C20METH = . if (C20METH <= -1 )
replace C20AMETH = . if (C20AMETH <= -1 )
replace C21METH = . if (C21METH <= -1 )
replace C16DOWN = . if (C16DOWN <= -1 )
replace C17DOWN = . if (C17DOWN <= -1 )
replace C18DOWN = . if (C18DOWN <= -1 )
replace C18ADOWN = . if (C18ADOWN <= -1 )
replace C19DOWN = . if (C19DOWN <= -1 )
replace C19ADOWN = . if (C19ADOWN <= -1 )
replace C20DOWN = . if (C20DOWN <= -1 )
replace C20ADOWN = . if (C20ADOWN <= -1 )
replace C21DOWN = . if (C21DOWN <= -1 )
replace C16OTHR = . if (C16OTHR <= -1 )
replace C17OTHR = . if (C17OTHR <= -1 )
replace C18OTHR = . if (C18OTHR <= -1 )
replace C18AOTHR = . if (C18AOTHR <= -1 )
replace C19OTHR = . if (C19OTHR <= -1 )
replace C19AOTHR = . if (C19AOTHR <= -1 )
replace C20OTHR = . if (C20OTHR <= -1 )
replace C20AOTHR = . if (C20AOTHR <= -1 )
replace C21OTHR = . if (C21OTHR <= -1 )
replace C22 = . if (C22 <= -1 )
replace C23 = . if (C23 <= -1 )
replace C24_1 = . if (C24_1 <= -1 )
replace C25_1 = . if (C25_1 <= -1.0 )
replace C25_1A = . if (C25_1A <= -1 )
replace C24_2 = . if (C24_2 <= -1 )
replace C25_2 = . if (C25_2 <= -1.0 )
replace C25_2A = . if (C25_2A <= -1 )
replace C24_3 = . if (C24_3 <= -1 )
replace C25_3 = . if (C25_3 <= -1.00 )
replace C25_3A = . if (C25_3A <= -1 )
replace C27 = . if (C27 <= -1 )
replace C27A = . if (C27A <= -1 )
replace C27B = . if (C27B <= -1 )
replace C28 = . if (C28 <= -1 )
replace C28A = . if (C28A <= -1 )
replace C28B = . if (C28B <= -1 )
replace C28CA = . if (C28CA <= -1 )
replace C28CB = . if (C28CB <= -1 )
replace C28CC = . if (C28CC <= -1 )
replace C29 = . if (C29 <= -1 )
replace C29A = . if (C29A <= -1 )
replace D1 = . if (D1 <= -1 )
replace D1A = . if (D1A <= -1 )
replace D2 = . if (D2 <= -1 )
replace D3 = . if (D3 <= -1 )
replace D4 = . if (D4 <= -1 )
replace D5 = . if (D5 <= -1 )
replace D6A = . if (D6A <= -1 )
replace D6B = . if (D6B <= -1 )
replace D6C = . if (D6C <= -1 )
replace D6D = . if (D6D <= -1 )
replace D6E = . if (D6E <= -1 )
replace D6F = . if (D6F <= -1 )
replace D6G = . if (D6G <= -1 )
replace D7 = . if (D7 <= -1 )
replace D7AA = . if (D7AA <= -1 )
replace D7BA = . if (D7BA <= -1 )
replace D7AB = . if (D7AB <= -1 )
replace D7BB = . if (D7BB <= -1 )
replace D7AC = . if (D7AC <= -1 )
replace D7BC = . if (D7BC <= -1 )
replace D7AD = . if (D7AD <= -1 )
replace D7BD = . if (D7BD <= -1 )
replace D7AE = . if (D7AE <= -1 )
replace D7BE = . if (D7BE <= -1 )
replace D7AF = . if (D7AF <= -1 )
replace D7BF = . if (D7BF <= -1 )
replace D7AG = . if (D7AG <= -1 )
replace D7BG = . if (D7BG <= -1 )
replace D8 = . if (D8 <= -1 )
replace D9 = . if (D9 <= -1 )
replace D9A_1 = . if (D9A_1 <= -1 )
replace D9A_2 = . if (D9A_2 <= -1 )
replace D9A_3 = . if (D9A_3 <= -1 )
replace D9A_4 = . if (D9A_4 <= -1 )
replace D9A_5 = . if (D9A_5 <= -1 )
replace D9A_6 = . if (D9A_6 <= -1 )
replace D9A_7 = . if (D9A_7 <= -1 )
replace D9A_8 = . if (D9A_8 <= -1 )
replace D9A_9 = . if (D9A_9 <= -1 )
replace D9A_10 = . if (D9A_10 <= -1 )
replace D9A_11 = . if (D9A_11 <= -1 )
replace D9A_12 = . if (D9A_12 <= -1 )
replace D9A_13 = . if (D9A_13 <= -1 )
replace D9A_14 = . if (D9A_14 <= -1 )
replace D9A_15 = . if (D9A_15 <= -1 )
replace D10 = . if (D10 <= -1 )
replace D10A = . if (D10A <= -1 )
replace D11 = . if (D11 <= -1 )
replace D12A = . if (D12A <= -1 )
replace D13A = . if (D13A <= -1 )
replace D13ANUM = . if (D13ANUM <= -1 )
replace D12B = . if (D12B <= -1 )
replace D13B = . if (D13B <= -1 )
replace D13BNUM = . if (D13BNUM <= -1 )
replace D12C = . if (D12C <= -1 )
replace D13C = . if (D13C <= -1 )
replace D13CNUM = . if (D13CNUM <= -1 )
replace D12D = . if (D12D <= -1 )
replace D13D = . if (D13D <= -1 )
replace D13DNUM = . if (D13DNUM <= -1 )
replace D12E = . if (D12E <= -1 )
replace D13E = . if (D13E <= -1 )
replace D13ENUM = . if (D13ENUM <= -1 )
replace D12F = . if (D12F <= -1 )
replace D13F = . if (D13F <= -1 )
replace D13FNUM = . if (D13FNUM <= -1 )
replace D12G = . if (D12G <= -1 )
replace D13G = . if (D13G <= -1 )
replace D13GNUM = . if (D13GNUM <= -1 )
replace D14 = . if (D14 <= -1 )
replace D14A = . if (D14A <= -1 )
replace D15 = . if (D15 <= -1 )
replace D15A = . if (D15A <= -1 )
replace D15B = . if (D15B <= -1 )
replace D16A = . if (D16A <= -1 )
replace D17A = . if (D17A <= -1 )
replace D16B = . if (D16B <= -1 )
replace D17B = . if (D17B <= -1 )
replace D16C = . if (D16C <= -1 )
replace D17C = . if (D17C <= -1 )
replace D16D = . if (D16D <= -1 )
replace D17D = . if (D17D <= -1 )
replace D16E = . if (D16E <= -1 )
replace D17E = . if (D17E <= -1 )
replace D16F = . if (D16F <= -1 )
replace D17F = . if (D17F <= -1 )
replace D16G = . if (D16G <= -1 )
replace D17G = . if (D17G <= -1 )
replace D18 = . if (D18 <= -1 )
replace D19 = . if (D19 <= -1 )
replace D20 = . if (D20 <= -1 )
replace D20A = . if (D20A <= -1 )
replace D20B = . if (D20B <= -1 )
replace D20C = . if (D20C <= -1 )
replace D20D = . if (D20D <= -1 )
replace D20E = . if (D20E <= -1 )
replace D20F = . if (D20F <= -1 )
replace D21 = . if (D21 <= -1 )
replace D21A = . if (D21A <= -1 )
replace D21B = . if (D21B <= -1 )
replace D21C = . if (D21C <= -1 )
replace D21D = . if (D21D <= -1 )
replace D21E = . if (D21E <= -1 )
replace D21F = . if (D21F <= -1 )
replace D22 = . if (D22 <= -1 )
replace D22A = . if (D22A <= -1 )
replace D22B = . if (D22B <= -1 )
replace D22C = . if (D22C <= -1 )
replace D22D = . if (D22D <= -1 )
replace D22E = . if (D22E <= -1 )
replace D22F = . if (D22F <= -1 )
replace D23 = . if (D23 <= -1 )
replace D23A = . if (D23A <= -1 )
replace D23B = . if (D23B <= -1 )
replace D23C = . if (D23C <= -1 )
replace D23D = . if (D23D <= -1 )
replace D23E = . if (D23E <= -1 )
replace D23F = . if (D23F <= -1 )
replace D24 = . if (D24 <= -1 )
replace D24A = . if (D24A <= -1 )
replace D24B = . if (D24B <= -1 )
replace D24C = . if (D24C <= -1 )
replace D24D = . if (D24D <= -1 )
replace D24E = . if (D24E <= -1 )
replace D24F = . if (D24F <= -1 )
replace D25 = . if (D25 <= -1 )
replace D25A = . if (D25A <= -1 )
replace D25B = . if (D25B <= -1 )
replace D25C = . if (D25C <= -1 )
replace D25D = . if (D25D <= -1 )
replace D25E = . if (D25E <= -1 )
replace D25F = . if (D25F <= -1 )
replace D26 = . if (D26 <= -1 )
replace D26A = . if (D26A <= -1 )
replace D26B = . if (D26B <= -1 )
replace D26C = . if (D26C <= -1 )
replace D26D = . if (D26D <= -1 )
replace D26E = . if (D26E <= -1 )
replace D26F = . if (D26F <= -1 )
replace D27 = . if (D27 <= -1 )
replace D27A = . if (D27A <= -1 )
replace D27B = . if (D27B <= -1 )
replace D27C = . if (D27C <= -1 )
replace D27D = . if (D27D <= -1 )
replace D27E = . if (D27E <= -1 )
replace D27F = . if (D27F <= -1 )
replace D28 = . if (D28 <= -1 )
replace D28A = . if (D28A <= -1 )
replace D28B = . if (D28B <= -1 )
replace D28C = . if (D28C <= -1 )
replace D28D = . if (D28D <= -1 )
replace D28E = . if (D28E <= -1 )
replace D28F = . if (D28F <= -1 )
replace D29 = . if (D29 <= -1 )
replace D29A = . if (D29A <= -1 )
replace D29B = . if (D29B <= -1 )
replace D29C = . if (D29C <= -1 )
replace D29D = . if (D29D <= -1 )
replace D29E = . if (D29E <= -1 )
replace D29F = . if (D29F <= -1 )
replace D30 = . if (D30 <= -1 )
replace D30A = . if (D30A <= -1 )
replace D30B = . if (D30B <= -1 )
replace D30C = . if (D30C <= -1 )
replace D30D = . if (D30D <= -1 )
replace D30E = . if (D30E <= -1 )
replace D30F = . if (D30F <= -1 )
replace D31 = . if (D31 <= -1 )
replace D31A = . if (D31A <= -1 )
replace D31B = . if (D31B <= -1 )
replace D31C = . if (D31C <= -1 )
replace D31D = . if (D31D <= -1 )
replace D31E = . if (D31E <= -1 )
replace D31F = . if (D31F <= -1 )
replace D32 = . if (D32 <= -1 )
replace D32A = . if (D32A <= -1 )
replace D32B = . if (D32B <= -1 )
replace D32C = . if (D32C <= -1 )
replace D32D = . if (D32D <= -1 )
replace D32E = . if (D32E <= -1 )
replace D32F = . if (D32F <= -1 )
replace D33 = . if (D33 <= -1 )
replace D33A = . if (D33A <= -1 )
replace D33B = . if (D33B <= -1 )
replace D33C = . if (D33C <= -1 )
replace D33D = . if (D33D <= -1 )
replace D33E = . if (D33E <= -1 )
replace D33F = . if (D33F <= -1 )
replace D34 = . if (D34 <= -1 )
replace D34A = . if (D34A <= -1 )
replace D34B = . if (D34B <= -1 )
replace D34C = . if (D34C <= -1 )
replace D34D = . if (D34D <= -1 )
replace D34E = . if (D34E <= -1 )
replace D34F = . if (D34F <= -1 )
replace D35 = . if (D35 <= -1 )
replace D35A = . if (D35A <= -1 )
replace D35B = . if (D35B <= -1 )
replace D35C = . if (D35C <= -1 )
replace D35D = . if (D35D <= -1 )
replace D35E = . if (D35E <= -1 )
replace D35F = . if (D35F <= -1 )
replace D36 = . if (D36 <= -1 )
replace D36AA = . if (D36AA <= -1 )
replace D36AB = . if (D36AB <= -1 )
replace D36AC = . if (D36AC <= -1 )
replace D35AD = . if (D35AD <= -1 )
replace E1 = . if (E1 <= -1 )
replace E1A = . if (E1A <= -1 )
replace E2 = . if (E2 <= -1 )
replace E3 = . if (E3 <= -1 )
replace E4MONTH = . if (E4MONTH <= -1 )
replace E4YEAR = . if (E4YEAR <= -1 )
replace E5 = . if (E5 <= -1 )
replace E6 = . if (E6 <= -1 )
replace E7 = . if (E7 <= -1 )
replace E8A = . if (E8A <= -1 )
replace E8B = . if (E8B <= -1 )
replace E9 = . if (E9 <= -1 )
replace E10 = . if (E10 <= -1 )
replace F1 = . if (F1 <= -1 )
replace F2 = . if (F2 <= -1 )
replace F3 = . if (F3 <= -1 )
replace F3A = . if (F3A <= -1 )
replace F3B = . if (F3B <= -1 )
replace F4 = . if (F4 <= -1 )
replace F5 = . if (F5 <= -1 )
replace F5A = . if (F5A <= -1 )
replace F6 = . if (F6 <= -1 )
replace F6A = . if (F6A <= -1 )
replace F7 = . if (F7 <= -1 )
replace F8 = . if (F8 <= -1 )
replace F8A = . if (F8A <= -1 )
replace F9 = . if (F9 <= -1 )
replace F10 = . if (F10 <= -1 )
replace F10A = . if (F10A <= -1 )
replace F11 = . if (F11 <= -1 )
replace F11A = . if (F11A <= -1 )
replace F12 = . if (F12 <= -1 )
replace F12A = . if (F12A <= -1 )
replace F13 = . if (F13 <= -1 )
replace F13A = . if (F13A <= -1 )
replace F13B = . if (F13B <= -1 )
replace F13C = . if (F13C <= -1 )
replace F13D = . if (F13D <= -1 )
replace F13E = . if (F13E <= -1 )
replace F13F = . if (F13F <= -1 )
replace F14 = . if (F14 <= -1 )
replace F14A = . if (F14A <= -1 )
replace F15 = . if (F15 <= -1 )
replace F15A = . if (F15A <= -1 )
replace F15B = . if (F15B <= -1 )
replace F15C = . if (F15C <= -1 )
replace F16 = . if (F16 <= -1 )
replace F16A = . if (F16A <= -1 )
replace F17 = . if (F17 <= -1 )
replace F17A = . if (F17A <= -1 )
replace F17B = . if (F17B <= -1 )
replace F17C = . if (F17C <= -1 )
replace F19 = . if (F19 <= -1 )
replace F19A_1 = . if (F19A_1 <= -1 )
replace F19A_2 = . if (F19A_2 <= -1 )
replace F19A_3 = . if (F19A_3 <= -1 )
replace F19A_4 = . if (F19A_4 <= -1 )
replace F19A_5 = . if (F19A_5 <= -1 )
replace F19A_6 = . if (F19A_6 <= -1 )
replace F19A_7 = . if (F19A_7 <= -1 )
replace F19A_8 = . if (F19A_8 <= -1 )
replace F19A_9 = . if (F19A_9 <= -1 )
replace F19A_10 = . if (F19A_10 <= -1 )
replace F19B_0 = . if (F19B_0 <= -1 )
replace F19B_1 = . if (F19B_1 <= -1 )
replace F19B_2 = . if (F19B_2 <= -1 )
replace F19B_3 = . if (F19B_3 <= -1 )
replace F19B_4 = . if (F19B_4 <= -1 )
replace F19B_5 = . if (F19B_5 <= -1 )
replace F19B_6 = . if (F19B_6 <= -1 )
replace F19B_7 = . if (F19B_7 <= -1 )
replace F19B_8 = . if (F19B_8 <= -1 )
replace F19B_9 = . if (F19B_9 <= -1 )
replace F19B_10 = . if (F19B_10 <= -1 )
replace F19B_11 = . if (F19B_11 <= -1 )
replace F19B_12 = . if (F19B_12 <= -1 )
replace F19B_13 = . if (F19B_13 <= -1 )
replace F19B_14 = . if (F19B_14 <= -1 )
replace F19B_15 = . if (F19B_15 <= -1 )
replace F19B_16 = . if (F19B_16 <= -1 )
replace F19B_17 = . if (F19B_17 <= -1 )
replace F19C = . if (F19C <= -1 )
replace G1 = . if (G1 <= -1 )
replace G2 = . if (G2 <= -1 )
replace G3 = . if (G3 <= -1 )
replace G3A = . if (G3A <= -1 )
replace G3B = . if (G3B <= -1 )
replace G4 = . if (G4 <= -1 )
replace G5 = . if (G5 <= -1 )
replace G6 = . if (G6 <= -1 )
replace G7 = . if (G7 <= -1 )
replace G8 = . if (G8 <= -1 )
replace G9 = . if (G9 <= -1 )
replace G10 = . if (G10 <= -1 )
replace G11 = . if (G11 <= -1 )
replace G12 = . if (G12 <= -1 )
replace G13 = . if (G13 <= -1 )
replace G14 = . if (G14 <= -1 )
replace G15 = . if (G15 <= -1 )
replace G16 = . if (G16 <= -1 )
replace G17 = . if (G17 <= -1 )
replace G18 = . if (G18 <= -1 )
replace G19 = . if (G19 <= -1 )
replace G20 = . if (G20 <= -1 )
replace G20A = . if (G20A <= -1 )
replace G20B = . if (G20B <= -1 )
replace G21 = . if (G21 <= -1 )
replace G22 = . if (G22 <= -1 )
replace G23 = . if (G23 <= -1 )
replace G24 = . if (G24 <= -1 )
replace G25 = . if (G25 <= -1 )
replace G26 = . if (G26 <= -1 )
replace G27 = . if (G27 <= -1 )
replace G28 = . if (G28 <= -1 )
replace G28A = . if (G28A <= -1 )
replace G28B = . if (G28B <= -1 )
replace G29 = . if (G29 <= -1 )
replace G30 = . if (G30 <= -1 )
replace G31 = . if (G31 <= -1 )
replace G32 = . if (G32 <= -1 )
replace G33 = . if (G33 <= -1 )
replace G34 = . if (G34 <= -1 )
replace G35 = . if (G35 <= -1 )
replace G36 = . if (G36 <= -1 )
replace G37 = . if (G37 <= -1 )
replace G38 = . if (G38 <= -1 )
replace G39 = . if (G39 <= -1 )
replace G40 = . if (G40 <= -1 )
replace G41 = . if (G41 <= -1 )
replace G42 = . if (G42 <= -1 )
replace G43 = . if (G43 <= -1 )
replace G44 = . if (G44 <= -1 )
replace G45 = . if (G45 <= -1 )
replace G46 = . if (G46 <= -1 )
replace G47 = . if (G47 <= -1 )
replace G48 = . if (G48 <= -1 )
replace G49 = . if (G49 <= -1 )
replace G50 = . if (G50 <= -1 )
replace G51A = . if (G51A <= -1 )
replace G51B = . if (G51B <= -1 )
replace G51C = . if (G51C <= -1 )
replace G51D = . if (G51D <= -1 )
replace G51E = . if (G51E <= -1 )
replace G51F = . if (G51F <= -1 )
replace G51G = . if (G51G <= -1 )
replace G51H = . if (G51H <= -1 )
replace G51I = . if (G51I <= -1 )
replace G51J = . if (G51J <= -1 )
replace G51K = . if (G51K <= -1 )
replace G51AA = . if (G51AA <= -1 )
replace G51BA = . if (G51BA <= -1 )
replace G51AB = . if (G51AB <= -1 )
replace G51BB = . if (G51BB <= -1 )
replace G51AC = . if (G51AC <= -1 )
replace G51BC = . if (G51BC <= -1 )
replace G51AD = . if (G51AD <= -1 )
replace G51BD = . if (G51BD <= -1 )
replace G51AE = . if (G51AE <= -1 )
replace G51BE = . if (G51BE <= -1 )
replace G51AF = . if (G51AF <= -1 )
replace G51BF = . if (G51BF <= -1 )
replace G51AG = . if (G51AG <= -1 )
replace G51BG = . if (G51BG <= -1 )
replace G51AH = . if (G51AH <= -1 )
replace G51BH = . if (G51BH <= -1 )
replace G51AI = . if (G51AI <= -1 )
replace G51BI = . if (G51BI <= -1 )
replace G51AJ = . if (G51AJ <= -1 )
replace G51BJ = . if (G51BJ <= -1 )
replace G51AK = . if (G51AK <= -1 )
replace G51BK = . if (G51BK <= -1 )
replace G52 = . if (G52 <= -1 )
replace G53 = . if (G53 <= -1 )
replace G54 = . if (G54 <= -1 )
replace G55 = . if (G55 <= -1 )
replace G56 = . if (G56 <= -1 )
replace G57 = . if (G57 <= -1 )
replace G58 = . if (G58 <= -1 )
replace G59 = . if (G59 <= -1 )
replace G60 = . if (G60 <= -1 )
replace G61 = . if (G61 <= -1 )
replace G62 = . if (G62 <= -1 )
replace G63 = . if (G63 <= -1 )
replace G64 = . if (G64 <= -1 )
replace G65 = . if (G65 <= -1 )
replace G66 = . if (G66 <= -1 )
replace G67 = . if (G67 <= -1 )
replace G68 = . if (G68 <= -1 )
replace G69 = . if (G69 <= -1 )
replace G70 = . if (G70 <= -1 )
replace G71 = . if (G71 <= -1 )
replace G72 = . if (G72 <= -1 )
replace G73 = . if (G73 <= -1 )
replace G74 = . if (G74 <= -1 )
replace G75 = . if (G75 <= -1 )
replace G76 = . if (G76 <= -1 )
replace G77 = . if (G77 <= -1 )
replace G78 = . if (G78 <= -1 )
replace G79 = . if (G79 <= -1 )
replace G80 = . if (G80 <= -1 )
replace G81 = . if (G81 <= -1 )
replace G82 = . if (G82 <= -1 )
replace G83 = . if (G83 <= -1 )
replace G84 = . if (G84 <= -1 )
replace G86 = . if (G86 <= -1 )
replace G87 = . if (G87 <= -1 )
replace G88 = . if (G88 <= -1 )
replace G89 = . if (G89 <= -1 )
replace G90 = . if (G90 <= -1 )
replace G91 = . if (G91 <= -1 )
replace G92 = . if (G92 <= -1 )
replace G93 = . if (G93 <= -1 )
replace G95 = . if (G95 <= -1 )
replace G96 = . if (G96 <= -1 )
replace G97 = . if (G97 <= -1 )
replace G98 = . if (G98 <= -1 )
replace G99 = . if (G99 <= -1 )
replace H1 = . if (H1 <= -1 )
replace H2 = . if (H2 <= -1 )
replace H3 = . if (H3 <= -1 )
replace H3BDOL = . if (H3BDOL <= -1.00 )
replace H3BRATE = . if (H3BRATE <= -1 )
replace H4 = . if (H4 <= -1 )
replace H4ADOL = . if (H4ADOL <= -1.00 )
replace H4ARATE = . if (H4ARATE <= -1 )
replace SAME1ST = . if (SAME1ST <= -1 )
replace H6 = . if (H6 <= -1 )
replace H7 = . if (H7 <= -1 )
replace SAME2ND = . if (SAME2ND <= -1 )
replace H7BDOL = . if (H7BDOL <= -1.00 )
replace H7ARATE = . if (H7ARATE <= -1 )
replace H8 = . if (H8 <= -1 )
replace H8ADOL = . if (H8ADOL <= -1.00 )
replace H8ARATE = . if (H8ARATE <= -1 )
replace SAME3RD = . if (SAME3RD <= -1 )
replace H10 = . if (H10 <= -1 )
replace H10A = . if (H10A <= -1 )
replace H10BDOL = . if (H10BDOL <= -1.00 )
replace H10BRTE = . if (H10BRTE <= -1 )
replace SAME4TH = . if (SAME4TH <= -1 )
replace H11 = . if (H11 <= -1 )
replace H12 = . if (H12 <= -1 )
replace H13 = . if (H13 <= -1 )
replace SAME5TH = . if (SAME5TH <= -1 )
replace H13BDOL = . if (H13BDOL <= -1.00 )
replace H13BRTE = . if (H13BRTE <= -1 )
replace H14 = . if (H14 <= -1 )
replace H14ADOL = . if (H14ADOL <= -1.00 )
replace H14ARTE = . if (H14ARTE <= -1 )
replace SAME6TH = . if (SAME6TH <= -1 )
replace H15 = . if (H15 <= -1 )
replace SAME7TH = . if (SAME7TH <= -1 )
replace H15B = . if (H15B <= -1 )
replace H15CDOL = . if (H15CDOL <= -1.00 )
replace H15CRTE = . if (H15CRTE <= -1 )
replace H17 = . if (H17 <= -1 )
replace H17A = . if (H17A <= -1 )
replace H17BDOL = . if (H17BDOL <= -1.00 )
replace H17BRTE = . if (H17BRTE <= -1 )
replace SAME8TH = . if (SAME8TH <= -1 )
replace H19 = . if (H19 <= -1 )
replace H19A_1 = . if (H19A_1 <= -1 )
replace H19A_2 = . if (H19A_2 <= -1 )
replace H19A_3 = . if (H19A_3 <= -1 )
replace H19A_4 = . if (H19A_4 <= -1 )
replace H19A_5 = . if (H19A_5 <= -1 )
replace H19A_6 = . if (H19A_6 <= -1 )
replace H19A_7 = . if (H19A_7 <= -1 )
replace H19A_8 = . if (H19A_8 <= -1 )
replace H19B = . if (H19B <= -1 )
replace H21A = . if (H21A <= -1 )
replace H22A = . if (H22A <= -1.00 )
replace H22ATIM = . if (H22ATIM <= -1 )
replace H21B = . if (H21B <= -1 )
replace H22B = . if (H22B <= -1.00 )
replace H22BTIM = . if (H22BTIM <= -1 )
replace H21C = . if (H21C <= -1 )
replace H22C = . if (H22C <= -1.00 )
replace H22CTIM = . if (H22CTIM <= -1 )
replace H21D = . if (H21D <= -1 )
replace H22D = . if (H22D <= -1.00 )
replace H22DTIM = . if (H22DTIM <= -1 )
replace H21E = . if (H21E <= -1 )
replace H22E = . if (H22E <= -1 )
replace H22ETIM = . if (H22ETIM <= -1 )
replace H21F = . if (H21F <= -1 )
replace H22F = . if (H22F <= -1.00 )
replace H22FTIM = . if (H22FTIM <= -1 )
replace H21G = . if (H21G <= -1 )
replace H22G = . if (H22G <= -1 )
replace H22GTIM = . if (H22GTIM <= -1 )
replace H21H = . if (H21H <= -1 )
replace H22H = . if (H22H <= -1.00 )
replace H22HTIM = . if (H22HTIM <= -1 )
replace PHONE1 = . if (PHONE1 <= -1 )
replace PHONE2 = . if (PHONE2 <= -1 )
replace PERSON2 = . if (PERSON2 <= -1 )
replace PHONE3 = . if (PHONE3 <= -1 )
replace ENDYEAR = . if (ENDYEAR <= -1 )
replace TOTTIME = . if (TOTTIME <= -1 )
replace BOXII = . if (BOXII <= -1 )
replace BOXIII = . if (BOXIII <= -1 )
replace BOXIV = . if (BOXIV <= -1 )
replace BOXRECPT = . if (BOXRECPT <= -1 )
replace I11A = . if (I11A <= -1 )
replace I11AA = . if (I11AA <= -1 )
replace I11AB = . if (I11AB <= -1 )
replace I11B = . if (I11B <= -1 )
replace I11BA = . if (I11BA <= -1 )
replace I11BB = . if (I11BB <= -1 )
replace I11C = . if (I11C <= -1 )
replace I11CA = . if (I11CA <= -1 )
replace I11CB = . if (I11CB <= -1 )
replace I11D = . if (I11D <= -1 )
replace I11DA = . if (I11DA <= -1 )
replace I11DB = . if (I11DB <= -1 )
replace I11E = . if (I11E <= -1 )
replace I11EA = . if (I11EA <= -1 )
replace I11EB = . if (I11EB <= -1 )
replace I11F = . if (I11F <= -1 )
replace I11FA = . if (I11FA <= -1 )
replace I11FB = . if (I11FB <= -1 )
replace I11G = . if (I11G <= -1 )
replace I11GA = . if (I11GA <= -1 )
replace I11GB = . if (I11GB <= -1 )
replace I11AC = . if (I11AC <= -1 )
replace I11BC = . if (I11BC <= -1 )
replace I11CC = . if (I11CC <= -1 )
replace I11DC = . if (I11DC <= -1 )
replace I11EC = . if (I11EC <= -1 )
replace I11FC = . if (I11FC <= -1 )
replace I11GC = . if (I11GC <= -1 )
replace D6A_1 = . if (D6A_1 <= -1 )
replace INHAL = . if (INHAL <= -1 )
replace ALCOHOL = . if (ALCOHOL <= -1 )
replace MARIJUAN = . if (MARIJUAN <= -1 )
replace CRACK = . if (CRACK <= -1 )
replace COCAINE = . if (COCAINE <= -1 )
replace PCP = . if (PCP <= -1 )
replace HALLUCIN = . if (HALLUCIN <= -1 )
replace HEROIN = . if (HEROIN <= -1 )
replace ILLMETH = . if (ILLMETH <= -1 )
replace NARC = . if (NARC <= -1 )
replace METHAMPH = . if (METHAMPH <= -1 )
replace DOWNERS = . if (DOWNERS <= -1 )
replace OTHDRUG = . if (OTHDRUG <= -1 )
replace AGEFINH = . if (AGEFINH <= -1 )
replace AGEFALC = . if (AGEFALC <= -1 )
replace AGEFMAR = . if (AGEFMAR <= -1 )
replace AGFCRK = . if (AGFCRK <= -1 )
replace AGEFCOC = . if (AGEFCOC <= -1 )
replace AGEFPCP = . if (AGEFPCP <= -1 )
replace AGEFHAL = . if (AGEFHAL <= -1 )
replace AGEFHER = . if (AGEFHER <= -1 )
replace AGEFMTH = . if (AGEFMTH <= -1 )
replace AGEFNAR = . if (AGEFNAR <= -1 )
replace AGEFAMP = . if (AGEFAMP <= -1 )
replace AGEFDWN = . if (AGEFDWN <= -1 )
replace AGEFOTH = . if (AGEFOTH <= -1 )
replace USBINH = . if (USBINH <= -1 )
replace USBALC = . if (USBALC <= -1 )
replace USBMAR = . if (USBMAR <= -1 )
replace USBCRK = . if (USBCRK <= -1 )
replace USBCOC = . if (USBCOC <= -1 )
replace USBPCP = . if (USBPCP <= -1 )
replace USBHAL = . if (USBHAL <= -1 )
replace USBHER = . if (USBHER <= -1 )
replace USBMTH = . if (USBMTH <= -1 )
replace USBNAR = . if (USBNAR <= -1 )
replace USBAMP = . if (USBAMP <= -1 )
replace USBDWN = . if (USBDWN <= -1 )
replace USBOTH = . if (USBOTH <= -1 )
replace USBDINH = . if (USBDINH <= -1 )
replace USBDALC = . if (USBDALC <= -1 )
replace USBDMAR = . if (USBDMAR <= -1 )
replace USBDCRK = . if (USBDCRK <= -1 )
replace USBDCOC = . if (USBDCOC <= -1 )
replace USBDPCP = . if (USBDPCP <= -1 )
replace USBDHAL = . if (USBDHAL <= -1 )
replace USBDHER = . if (USBDHER <= -1 )
replace USBDMTH = . if (USBDMTH <= -1 )
replace USBDNAR = . if (USBDNAR <= -1 )
replace USBDAMP = . if (USBDAMP <= -1 )
replace USBDDWN = . if (USBDDWN <= -1 )
replace USBDOTH = . if (USBDOTH <= -1 )
replace USAINH = . if (USAINH <= -1 )
replace USAALC = . if (USAALC <= -1 )
replace USAMAR = . if (USAMAR <= -1 )
replace USACRK = . if (USACRK <= -1 )
replace USACOC = . if (USACOC <= -1 )
replace USAPCP = . if (USAPCP <= -1 )
replace USAHAL = . if (USAHAL <= -1 )
replace USAHER = . if (USAHER <= -1 )
replace USAMTH = . if (USAMTH <= -1 )
replace USANAR = . if (USANAR <= -1 )
replace USAAMP = . if (USAAMP <= -1 )
replace USADWN = . if (USADWN <= -1 )
replace USAOTH = . if (USAOTH <= -1 )
replace USADINH = . if (USADINH <= -1 )
replace USADALC = . if (USADALC <= -1 )
replace USADMAR = . if (USADMAR <= -1 )
replace USADCRK = . if (USADCRK <= -1 )
replace USADCOC = . if (USADCOC <= -1 )
replace USADPCP = . if (USADPCP <= -1 )
replace USADHAL = . if (USADHAL <= -1 )
replace USADHER = . if (USADHER <= -1 )
replace USADMTH = . if (USADMTH <= -1 )
replace USADNAR = . if (USADNAR <= -1 )
replace USADAMP = . if (USADAMP <= -1 )
replace USADDWN = . if (USADDWN <= -1 )
replace USADOTH = . if (USADOTH <= -1 )
replace USYINH = . if (USYINH <= -1 )
replace USYALC = . if (USYALC <= -1 )
replace USYMAR = . if (USYMAR <= -1 )
replace USYCRK = . if (USYCRK <= -1 )
replace USYCOC = . if (USYCOC <= -1 )
replace USYPCP = . if (USYPCP <= -1 )
replace USYHAL = . if (USYHAL <= -1 )
replace USYHER = . if (USYHER <= -1 )
replace USYMTH = . if (USYMTH <= -1 )
replace USYNAR = . if (USYNAR <= -1 )
replace USYAMP = . if (USYAMP <= -1 )
replace USYDWN = . if (USYDWN <= -1 )
replace USYOTH = . if (USYOTH <= -1 )
replace USYDINH = . if (USYDINH <= -1 )
replace USYDALC = . if (USYDALC <= -1 )
replace USYDMAR = . if (USYDMAR <= -1 )
replace USYDCRK = . if (USYDCRK <= -1 )
replace USYDCOC = . if (USYDCOC <= -1 )
replace USYDPCP = . if (USYDPCP <= -1 )
replace USYDHAL = . if (USYDHAL <= -1 )
replace USYDHER = . if (USYDHER <= -1 )
replace USYDMTH = . if (USYDMTH <= -1 )
replace USYDNAR = . if (USYDNAR <= -1 )
replace USYDAMP = . if (USYDAMP <= -1 )
replace USYDDWN = . if (USYDDWN <= -1 )
replace USYDOTH = . if (USYDOTH <= -1 )
replace USNINH = . if (USNINH <= -1 )
replace USNALC = . if (USNALC <= -1 )
replace USNMAR = . if (USNMAR <= -1 )
replace USNCRK = . if (USNCRK <= -1 )
replace USNCOC = . if (USNCOC <= -1 )
replace USNPCP = . if (USNPCP <= -1 )
replace USNHAL = . if (USNHAL <= -1 )
replace USNHER = . if (USNHER <= -1 )
replace USNMTH = . if (USNMTH <= -1 )
replace USNNAR = . if (USNNAR <= -1 )
replace USNAMP = . if (USNAMP <= -1 )
replace USNDWN = . if (USNDWN <= -1 )
replace USNOTH = . if (USNOTH <= -1 )
replace USNMINH = . if (USNMINH <= -1 )
replace USNMALC = . if (USNMALC <= -1 )
replace USNMMAR = . if (USNMMAR <= -1 )
replace USNMCRK = . if (USNMCRK <= -1 )
replace USNMCOC = . if (USNMCOC <= -1 )
replace USNMPCP = . if (USNMPCP <= -1 )
replace USNMHAL = . if (USNMHAL <= -1 )
replace USNMHER = . if (USNMHER <= -1 )
replace USNMMTH = . if (USNMMTH <= -1 )
replace USNMNAR = . if (USNMNAR <= -1 )
replace USNMAMP = . if (USNMAMP <= -1 )
replace USNMDWN = . if (USNMDWN <= -1 )
replace USNMOTH = . if (USNMOTH <= -1 )
replace USMINH = . if (USMINH <= -1 )
replace USMALC = . if (USMALC <= -1 )
replace USMMAR = . if (USMMAR <= -1 )
replace USMCRK = . if (USMCRK <= -1 )
replace USMCOC = . if (USMCOC <= -1 )
replace USMPCP = . if (USMPCP <= -1 )
replace USMHAL = . if (USMHAL <= -1 )
replace USMHER = . if (USMHER <= -1 )
replace USMMTH = . if (USMMTH <= -1 )
replace USMNAR = . if (USMNAR <= -1 )
replace USMAMP = . if (USMAMP <= -1 )
replace USMDWN = . if (USMDWN <= -1 )
replace USMOTH = . if (USMOTH <= -1 )
replace USBSEC = . if (USBSEC <= -1 )
replace USASEC = . if (USASEC <= -1 )
replace USBANY = . if (USBANY <= -1 )
replace USAANY = . if (USAANY <= -1 )
replace TRTYPE = . if (TRTYPE <= -1 )
replace LOS = . if (LOS <= -1 )
replace LOSCAT = . if (LOSCAT <= -1 )
replace RACE = . if (RACE <= -1 )
replace DISAGE = . if (DISAGE <= -1 )
replace DISAGE2 = . if (DISAGE2 <= -1 )
replace PRETRT = . if (PRETRT <= -1 )
replace COMPTRT = . if (COMPTRT <= -1 )
replace AFTTRT = . if (AFTTRT <= -1 )
replace HELPTRT = . if (HELPTRT <= -1 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

